c=======================================================================
c***********************************************************************
      subroutine pft_estab(ngt)
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c     This routine estimates establishment success for plant types.
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/annee.common'
      include './com_18/climin0.common'
      include './com_18/climin.common'
      include './com_18/coord.common'
      include './com_18/cstmort.common'
      include './com_18/cte.common'
      include './com_18/disper.common'
      include './com_18/ecoin.common'
      include './com_18/estab.common'
      include './com_18/gddpix.common'
      include './com_18/inidata.common'
      include './com_18/monthcst.common'
      include './com_18/nspc.common'
      include './com_18/pho_sch.common'
      include './com_18/monwat.common'
      include './com_18/snow.common'
      include './com_18/temper.common'
      include './com_18/xlaic.common'

      real*4 watmin
c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer im,ip,mmm
      real*4 tot_frac

c------------------------------------------------  

      watmin = 1000.
      do im = 1, nm
       if (swcar(im).le.watmin) then
         watmin = swcar(im)
       endif
      enddo

      if (ifrac.eq.1) then
         do ip = 1, npft
         
            gdd_inf(ip) = gdd_est(ip) * (1.- delta_gdd5)
            gdd_sup(ip) = gdd_est(ip) * (1.+ delta_gdd5)
            
            Tmmin_inf(ip) = tcmax_est(ip) - delta_tmax
            Tmmin_sup(ip) = tcmax_est(ip) + delta_tmax
            
            watmin_inf(ip) = watmax_est(ip) * (1. -delta_watmax)
            watmin_sup(ip) = watmax_est(ip) * (1. +delta_watmax)

c            tot_frac = 0.
c            ylaimax_mean = 0.
      
c            do mmm = nherb+nshrub+1, npft0
c             if(mmm.ne.ip) then
c              ylaimax_mean = ylaimax_mean 
c     &          + yfrac_ini(mmm,ngt)*ylaimax_ini(mmm,ngt)
c              tot_frac = tot_frac + yfrac_ini(mmm,ngt)
c             endif
c            enddo
cc            write(*,*)' tot_frac = ',tot_frac
c            ylaimax_mean = ylaimax_mean/tot_frac  
            
c            ylai_inf = 1.
c            ylai_sup = 2.
c            ylai_est = 1.5          

            suc_est(ip,ngt) = pgerm(ip)
            if (gdd5.lt.gdd_inf(ip)) suc_est(ip,ngt) = 0.
            if (Tmmin.gt.Tmmin_sup(ip)) suc_est(ip,ngt) = 0.
            if (watmin.gt.watmin_sup(ip)) suc_est(ip,ngt) = 0.
c           if ((ip.eq.3.or.ip.eq.10.or.ip.eq.13.or.ip.eq.14.
c     &        or.ip.eq.16).and.nyear.ne.1) then    
C             if (xlmax(ip).gt.1.5) suc_est(ip,ngt) = 0.
c              if (ylaimax_mean.gt.ylai_est) suc_est(ip,ngt) = 0. 
c           endif           
            
            Fgdd5(ip) = 1.
            if (gdd_est(ip) .gt. 0. .and. gdd5.lt.gdd_sup(ip)) then
             if (gdd5.lt.gdd_inf(ip)) then 
              Fgdd5(ip) = 0.
             else 
              Fgdd5(ip)=(1./2.)*(1.+erf(xk_erf*(gdd5-gdd_est(ip))
     &                   /(delta_gdd5*gdd_est(ip))))
             endif
            endif
            
            FTmmin(ip) = 1.
            if (Tmmin.gt.Tmmin_inf(ip)) then
             if (Tmmin.gt.Tmmin_sup(ip)) then 
              FTmmin(ip) = 0.
             else 
              FTmmin(ip)=(1./2.)*(1.-erf(xk_erf*(Tmmin-tcmax_est(ip))
     &                  /(delta_tmax)))
             endif
            endif
            
            Fwatmin(ip) = 1.
            if(watmax_est(ip).gt.0. .and. 
     &         watmin.gt.watmin_inf(ip)) then
             if (watmin.gt.watmin_sup(ip)) then 
              Fwatmin(ip) = 0.
             else 
              Fwatmin(ip)=(1./2.)*(1.-erf(xk_erf*(watmin-watmax_est(ip))
     &                   /(delta_watmax*watmax_est(ip))))
             endif
            endif
            
            if(nyr_t.eq.0.and.imig.eq.1.and.ip.eq.isp
c           if(ip.eq.isp
     &       .and.irfg(ngt).ne.1) then    
     
              suc_est(ip,ngt) = 0.
             
            endif
            
         enddo


      else
         do ip = 1, npft
          if (frac(ip).le.1.e-7) then
            suc_est(ip,ngt) = 0.
          else
            suc_est(ip,ngt) = pgerm(ip)
          endif
          
            if(nyr_t.eq.0.and.imig.eq.1.and.ip.eq.isp
c           if(ip.eq.isp
     &       .and.irfg(ngt).ne.1) then      
         
              suc_est(ip,ngt) = 0.
             
          endif
          
         enddo
      endif 

      return
      end

c=======================================================================
c***********************************************************************
      subroutine cal_in
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c   this routine calculates the external conditions at an hourly
c   time step:
c 
c   temp   = air temperature (K);
c   hs     = air relative humidity;
c   apar   = absorbed irradiance at the leaf level 
c           (micromol m-2 s-1);
c   rbl    = aerodynamic + boundary layer resistance(m2 s /mol).
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/climin.common'
      include './com_18/cstpi.common'
      include './com_18/day_corr.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/ecopro.common'
      include './com_18/envi.common'
      include './com_18/ext_con.common'
      include './com_18/ext_con2.common'
      include './com_18/gridin2.common'
      include './com_18/hcst.common'
      include './com_18/h2ocst.common'
      include './com_18/nspc.common'
      include './com_18/heure.common'
      include './com_18/laiste.common'
      include './com_18/radcst.common'
      include './com_18/rblcst1.common'
      include './com_18/res_par.common'
      include './com_18/sol_in.common'
      include './com_18/solpar.common'
      include './com_18/temper.common'
      include './com_18/varday.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer iday,ih,ip,irad,jday,jday2,jd,ndmean_t,ndmean_w
      
      real*4 arglog0,cdel,ch0,clcd,cte,facto,fdif,fexpo
      real*4 ftrsdif,ftrsdir,h0,ho1,hoo
      real*4 qh2o,rm,sdel,sl
      real*4 slsd,sth,temp2,tempi,th,theta
      real*4 tmin_day,tmax_day,xpar
      real*4 unitchg,us,us0,xls      
      
      
c------------------------------------------------  

      dimension tmin_day(ndy),tmax_day(ndy),xpar(ndy)


c=======================================================================
c   loops over the days
c=======================================================================

      do iday = 1, nd
         tmin_day(iday) = tcel(iday) - tdiff(iday) / 2.
         tmax_day(iday) = tcel(iday) + tdiff(iday) / 2.

c=======================================================================
c   calculation of the daily mean atmospheric pressure of h2o.
c=======================================================================

         tempi = tcel(iday) + temp0
         if(tcel(iday) .ge. 0.) then
            fexpo = ah2o/tempi + bh2o*log10(tempi) + ch2o
            qh2o = 10.**fexpo
         else
            facto = tcel(iday) * eh2o / tempi
            qh2o = dh2o * exp(facto)
         endif
         qh2o = qh2o * rhu(iday)

c=======================================================================
c   calculation of angles necessary in the atmospheric radiative
c   transfert scheme:
c
c   sdel  = sinus of the declinaison;
c   h0    = hourly angle of the day beginning;
c   ftrs  = atmospheric transmittance(dimensionless).
c=======================================================================

         sl    = pi365 * (iday - 79.092)
         if(sl .lt. 0.) sl = pi2 + sl
         th    = sl - xlsper
         sth   = sin(th)
         xls   = sl + sth*exc6 + sth*cos(th)*exc7
     &         + (3.*sth - 13.*sth*sth*sth/3.) * exc5
         theta = xls - xlsper
         rm    = (1. - exc4) / (1. + exc*cos(theta))
         sdel  = sin(obl) * sin(xls)
         cdel  = sqrt(1.-sdel*sdel)
         cte   = sunea / (rm * rm)
         slsd  = slati * sdel
         clcd  = clati * cdel
         ch0   = -slsd / clcd

         if(ch0 .ge. 1.) then
            h0     = 0.
         else
            if(ch0 .le. -1) then
               h0  = pi
            else
               h0  = acos(ch0)
            endif
         endif

         ftrsdir = ftrmax*sunhour(iday)
         ftrsdif = ftrmin*(1. - sunhour(iday))
         xpar(iday) = 0.
         partoc(iday) = 0.
         do ih = 1, nh2
           do ip = 1, npft
               do irad = 1,3
                  apar(ip,iday,ih,irad) = 0.
               enddo
           end do
         enddo
         do ih = 1, nh2
            do ip = 1, nplant
               fsun(ip,iday,ih)  = 0.
            end do
         enddo

c=======================================================================
c   rbl = aerodynamic (rae) + boundary layer (rbw) resitance
c   rae in s m-1
c   rbw in s m-1
c=======================================================================

         if(win(iday) .lt. 0.1 ) win(iday) = 0.1

         us0 = win(iday) * arbl

         do ip = 1, npft
            arglog0 = (zzra(ip) - disd(ip)) / z0vs(ip)
            us      = us0 / log(arglog0)
            rae(ip,iday) = win(iday) / (us*us)
            rbw(ip,iday) = brbl / (us**exrbl)
            unitchg = unitfac*(1.+(tcel(iday)/temp0))
     &               *patm0/patm
            rbl(ip,iday) = (rae(ip,iday) + h2osurco2*rbw(ip,iday)) 
     &                   * unitchg
         enddo

c=======================================================================
c   loops over the hours
c=======================================================================

         do ih = 1, nh2

c=======================================================================
c   temperature estimates
c   temp(iday,ih) = air temperature (K)
c=======================================================================

            temp(iday,ih)  = temp0+tcel(iday)+0.5
     &                      *tdiff(iday)*cohour(ih)

c=======================================================================
c   air relative humidity estimates. It is supposed that the
c   atmospheric water content is constant during the day.
c   qsatmb = saturation vapor pressure (mbar)
c=======================================================================

            temp2 = temp(iday,ih) - temp0
            if(temp2 .ge. 0.) then
               fexpo  = ah2o/temp(iday,ih)+bh2o*log10(temp(iday,ih))
     &                + ch2o
               qsatmb(iday,ih) = 10.**fexpo
            else
               facto  = temp2 * eh2o / temp(iday,ih)
               qsatmb(iday,ih) = dh2o * exp(facto)
            endif

            hs(iday,ih) = qh2o / qsatmb(iday,ih)
            if(hs(iday,ih) .gt. 1.) hs(iday,ih) = 1.
            if(hs(iday,ih) .lt. 0.) hs(iday,ih) = 0.

c=======================================================================
c   calculation of the solar irradiance at the earth surface
c   solg   = hourly value of the surface solar 
c            irradiance for the grid point studied
c           (w m-2);
c   xmucar = cosine of the solar zenithal angle , one 
c            value at each hour (dimensionless).
c=======================================================================

            xmucar(iday,ih) = 0.
            do irad = 1, 3
               par0(iday,ih,irad) = 0.
            enddo
            corr_hour(iday,ih) = 0.

            if(abs(hour2(ih)) .lt. h0) then
               if(abs(hour1(ih)) .le. h0) then

                  xmucar(iday,ih) = slsd + clcd * codelhour(ih)
                  corr_hour(iday,ih) = 1.

               else

                  ho1 = -h0
                  hoo = (hour2(ih) + ho1) / 2.
                  xmucar(iday,ih) = slsd + clcd 
     &                            * (sin(hour2(ih)) - sin(ho1))
     &                            / (hour2(ih)  - ho1)
                  if(xmucar(iday,ih).lt.0.) xmucar(iday,ih) = 0.
                  corr_hour(iday,ih) = (h0 - abs(hour2(ih))) / h_step 
                  if(corr_hour(iday,ih).lt.0. .or.
     &               corr_hour(iday,ih).gt.1.) then
                     write(61,*) 'error, hour cor:', iday,ih,
     &                            corr_hour(iday,ih)
                     write(61,*) 'h_step', h_step
                  stop
                  endif

               endif
               if(xmucar(iday,ih).lt.0.) then
                  write(61,*) 'error sun angle = ',xmucar(iday,ih),
     &            'hour = ',ih
                  stop
               endif

               fdif = 0.2
               par0(iday,ih,1) = cte * xmucar(iday,ih) * ftrmax 
     &                         * (1.-fdif) * 0.45
               par0(iday,ih,2) = cte * xmucar(iday,ih) * ftrmax 
     &                         * fdif * 0.45    ! old value: 0.45     
               par0(iday,ih,3) = cte * xmucar(iday,ih) * ftrmin * 0.55
            endif

c=======================================================================
c   dirrad = direct irradiance (w m-2);
c   difrad = diffuse irradiance (w m-2);
c=======================================================================

            xpar(iday) = xpar(iday) + corr_hour(iday,ih) *
     &                 ( par0(iday,ih,1) * sunhour(iday) 
     &                 + par0(iday,ih,2) * sunhour(iday)
     &                 + par0(iday,ih,3) * (1. -sunhour(iday)))

         enddo

         partoc(iday) = xpar(iday)
         xpar(iday) = xpar(iday) * parun

      enddo

c=======================================================================
c   minimum and maximum temperature, soil water content and day 
c   length for the ndmean previous days.
c=======================================================================

      do iday = 1, nd

         tmin2(iday)       = 0.
         tmax2(iday)       = 0.
         xpar2(iday)       = 0.
         water2(iday)      = 0.

         ndmean_t=4
         do jday = 1, ndmean_t
          jday2 = iday - jday
          if(jday2 .le. 0) jday2 = jday2 + nd
          tmin2(iday)  = tmin2(iday)  + tmin_day(jday2)/float(ndmean_t)
          tmax2(iday)  = tmax2(iday)  + tmax_day(jday2)/float(ndmean_t)
          xpar2(iday)  = xpar2(iday)  + xpar(jday2) /float(ndmean_t)
         end do

         ndmean_w=7
         do jday = 1, ndmean_w
          jday2 = iday - jday
          if(jday2 .le. 0) jday2 = jday2 + nd    
          water2(iday) = water2(iday) + water(jday2)/float(ndmean_w)
         enddo

      enddo
 
      return
      end

c=======================================================================
c***********************************************************************
      subroutine ponc_init
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c   This routine performs the initialisation of:
c  
c   ynpp    = yearly npp;
c   ygpp    = yearly leaf gpp;
c   ynep    = yearly nep;
c   xmnpp   = daily leaf npp (gc m-2 d-1);
c   xmgpp   = daily gross primary productivity (gc m-2 d-1);
c   zgpp(ip,iday,nlai) = daily gpp for the grid point .
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/angppf.common'
      include './com_18/annppf.common'
      include './com_18/biomasse.common'
      include './com_18/burned.common'
      include './com_18/cmoiRmin.common'
      include './com_18/cte.common'
      include './com_18/dayres.common'
      include './com_18/fire_emi.common'      
      include './com_18/frac_change.common'
      include './com_18/fracc13.common'
      include './com_18/litiere.common'
      include './com_18/management.common'      
      include './com_18/monres.common'
      include './com_18/nspc.common'
      include './com_18/pnpp2.common'
      include './com_18/soil_marie.common'
      include './com_18/xvalues.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c

      integer iday,ip,ipool,kpool,m
      
c----------------------------------------------------
      do m = 1, nm
         xmgpp(m) = 0.
	 xmra(m) = 0.
         xmnpp(m) = 0.
         xmnep(m) = 0.
	 xmrh(m) = 0.
	 xmnbp(m) = 0.	 
	 xmemifire(m) = 0.
	 xmcharvest(m) = 0.
	 xmemiblit(m) = 0.
         xmlai(m) = 0.	 
         xmbiom(m) = 0.  
c  initialization of monthly variables of fire module
         xmPf(m) = 0.    
         xmPnf(m) = 1.
         xmfapar(m) = 0.
         xmfrac_burn(m) = 0.
         xmarea_burn(m) = 0.
      enddo

      do kpool = 0, 3
         ysoilr(kpool) = 0.
      end do

      do ip = 1, npft
         ynppf(ip)   = 0.
         ygppf(ip)   = 0.
         ybiomf(ip)  = 0.
         yfractf(ip) = 0.
         xlai_min(ip) = 0.
         xlai_max(ip) = 0.
         R_min(ip) = 0.
         xlai_moy(ip) = 0.
         fracnew(ip) = 0.
         frac_seed(ip) = 0.
         ycharvest(ip) = 0.
	 yemifiref(ip) = 0.                             
      enddo

      do iday = 1, nd
         xdnpp(iday)   = 0.
         xdgpp(iday)   = 0.
         xdnep(iday)   = 0.
	 xdnbp(iday)   = 0.	 
	 xdemifire(iday) = 0.
	 xdcharvest(iday) = 0.	 
	 emi_burn_lit(iday) = 0.
         xdlai(iday)   = 0.
         xdbiom(iday)  = 0.      
         xdfract(iday) = 0.
         xdfapar(iday) = 0.
         xdgca(iday)   = 0.
         xdgci(iday)   = 0.

         do kpool = 1, 2
          xhum_prod(kpool,iday) = 0.
         end do
         do ip = 1, npft
            xlai(ip,iday) = 0.
	    xemifire(ip,iday) = 0.
	    xcharvest(ip,iday) = 0.
            do ipool = 1, npool
               xlit_prod(ip,ipool,iday) = 0.
               xlit_newprod(ip,ipool,iday) = 0.
               xlit_burn(ip,ipool,iday) = 0.
	       emi_burn_veg(ip,ipool,iday) = 0.
            enddo

               zgpp(ip,iday) = 0.
CNPP               znpp(ip,iday) = 0.
               zfract(ip,iday) = 0.
               zfh2o(ip,iday) = 0.
	       
         enddo

      enddo


      return
      end

c=======================================================================
c***********************************************************************
      subroutine set_cpools(ngt)
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c   This routine reads initial value of carbon pools
c   and set them in the right form.
c=======================================================================
      include './com_18/parameter.common'
      include './com_18/annee.common'
      include './com_18/ecoin.common'
      include './com_18/init.common'
      include './com_18/inidata.common'
      include './com_18/nspc.common'
      include './com_18/plant_pool.common'
      include './com_18/plant_evol.common'
      include './com_18/prev_yr.common'
      include './com_18/soil_pool.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer iday,ip,ipool,kpool
      
      real*4 val_min_rese
c-----------------------------------------------

c=======================================================================
c   initial value of carbon pools.
c=======================================================================

      do iday = 1, nd-1
         xhumus(iday)    = 0.
         do kpool = 1, 2
           xlit(kpool,iday) = 0.
         end do
         do ip = 1, npft
            do ipool = 1, npool
               carbon(ip,ipool,iday) = 0.
            enddo
         enddo
      enddo

      do kpool = 1, 2
       xlit(kpool,nd) = ylit_ini(kpool,ngt)
      end do

      xhumus(nd) = yhum_ini(ngt)

      do ip = 1, npft
          do ipool = 1, npool
            carbon(ip,ipool,nd) = ycar_ini(ip,ipool,ngt)
c            if(nyr_t.eq.0. .and. suc_est(ip,ngt).gt.1.e-5) then
            if(frac(ip).gt.1.e-7) then
              if(carbon(ip,ipool,nd).le.0.)
     &           carbon(ip,ipool,nd) = carb_init(ip,ipool)

            endif
          enddo
          rese(ip) = yrese_ini(ip,ngt)
c          if(nyr_t.eq.0. .and. suc_est(ip,ngt).gt.1.e-5) then
            val_min_rese = rese_frac(ip) * xip(ip,1) *
     &                (carbon(ip,2,nd)**xkappa(ip))
            if(rese(ip).lt.val_min_rese) rese(ip) = val_min_rese
c          endif
          ybinc_prv(ip) = ybinc_ini(ip,ngt)
      enddo

      if(nyr_t .eq. 0) then
         do ip = 1, npft
            if(suc_est(ip,ngt).le.1.e-5) then
               do ipool = 1, npool
                 carbon(ip,ipool,nd) = 0.
               enddo
               rese(ip) = 0.
	       ybinc_prv(ip) = 0.
            endif
         enddo
      endif


      return
      end

c=======================================================================
c***********************************************************************
      subroutine lailim_init
c***********************************************************************
c=======================================================================
      implicit none 
c=======================================================================
c   This routine reads initial value of lai limitation due to water 
c   stress
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/laiste.common'
      include './com_18/laih2o.common'
      include './com_18/nspc.common'
c-----------------------------------------------
c JLP ajouté pour implicit none
c      
      integer ip,m 
c------------------------------------------------

      do ip = 1, npft
       yminlai_w(ip) = xlaimax
       yvslai_w(ip) = 0.
       do m = 1, nm
         xlai_w(ip,m) = xlaimax
       end do
      enddo

      return
      end

c###########################################################################

c=======================================================================
c***********************************************************************
      subroutine npp_cal(ngt,ny0,iread,itmt,tmt_it)
c***********************************************************************
c=======================================================================
      implicit none 
c=======================================================================
c
c   this routine calculates the net primary productivity and the
c   co2 carbon pools.
c
c   Plant are divided in 3 pools:
c       1 = "green biomass" including leaves (and active roots);
c       2 = rest of the plant
c       3 = reserve
c
c   Pool values are determined resolving the differential equations:
c
c      dC/dt = Fin - Fout
c      where C    = carbon pool (g m-2);
c            t    = time (day);
c            Fin  = incoming fluxes (g m-2 d-1) expressed as a  
c                   fraction of the total gpp except for "green 
c                   biomass for which Fin comes also from reserves in
c                   the growing season;
c            Fout = outgoing fluxes (g m-2 d-1) supposed proportional
c                   to carbon pools (k*C) except growth respiration 
c                   supposed equal to 0 when Fout > Fin and equal to
c                   h * dC/dt in other cases (h = 0.20).
c   Supposing that Fin and K are constant during a time step (here 
c   one day) the solution of this equation is:
c
c      C = C0 exp(-k*t/(1+h)) + {1 - exp(-k*t/(1_h))}*Fin/{(1+h)*k}
c          where C0 is the initial value of the pool.
c
c   carbon(ip,ipool,iday) = C.
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/ageclas.common'
      include './com_18/annee.common'
      include './com_18/angppf.common'
      include './com_18/bagnum.common'
      include './com_18/biomasse.common'
      include './com_18/carbon_maxi.common'
      include './com_18/climin.common'
      include './com_18/cmoiRmin.common'
      include './com_18/coord.common'
      include './com_18/cte.common'
      include './com_18/day_corr.common'
      include './com_18/dayres.common'
      include './com_18/ecoin.common'
      include './com_18/ext_con.common'
      include './com_18/ext_con2.common'
      include './com_18/fire_emi.common'      
      include './com_18/fracc13.common'      
      include './com_18/gcaci2.common'
      include './com_18/gk.common'
      include './com_18/lai.common'
      include './com_18/laih2o.common'
      include './com_18/laiste.common'
      include './com_18/loop.common'
      include './com_18/management.common'      
      include './com_18/mois.common'
      include './com_18/monthcst.common'
      include './com_18/nspc.common'
      include './com_18/number_year.common'
      include './com_18/pho_sch.common'
      include './com_18/plant_evol.common'      
      include './com_18/plant_pool.common'
      include './com_18/pnpp2.common'      
      include './com_18/radcst.common'
      include './com_18/res_par.common'
      include './com_18/res_temp2.common'
      include './com_18/strate.common'
      include './com_18/tresh.common'
      include './com_18/xvalues.common'
      include './com_18/frac_change.common'

      
      
c-----------------------------------------------
c JLP ajouté pour implicit none
c      
      integer , intent(in) :: ngt,ny0,iread,itmt
      integer ih,ipool
      real*4  , intent(in) :: tmt_it
      real*4  faparl,tot_frac,faparh
c------------------------------------------------      

c   second argument of year_iteration : 
c   tree  = 0
c   grass = 1
c-----------------------------------------------------------------------

c=======================================================================
c     crops 
c=======================================================================

      nstrate = 0
      ipi = npft0+1
      ipf = npft0+ncrop

c=======================================================================
c     limite the lai due to water fluxes.. CARAIB and IBM have to be
c     coherent
c=======================================================================

      call wat_limit

c=======================================================================
c     carbon fluxes calulation
c=======================================================================

      call year_iteration(ngt,itmt,tmt_it)

      call lai_limit_w

c=======================================================================
c     pastures 
c=======================================================================

      nstrate = 0
      ipi = npft0+ncrop+1
      ipf = npft0+ncrop+npast

c=======================================================================
c     limite the lai due to water fluxes.. CARAIB and IBM have to be
c     coherent
c=======================================================================

      call wat_limit

c=======================================================================
c     carbon fluxes calulation
c=======================================================================

      call year_iteration(ngt,itmt,tmt_it)

      call lai_limit_w

c=======================================================================
c     trees
c=======================================================================

      nstrate = 0
      ipi = nherb+nbush+1
      ipf = npft0

c=======================================================================
c     limits the lai due to water fluxes.. CARAIB and IBM have to be
c     coherent
c=======================================================================

      call wat_limit

c=======================================================================
c     carbon fluxes calulation
c=======================================================================

      call year_iteration(ngt,itmt,tmt_it)

      call lai_limit_w

      if (ifrac.eq.1 .and.ny0.eq.1 .and. nyear.eq.1 .and. iread.eq.0
     &   .and. ifrac_rd.eq.0) 
     &   call frac_trees(ngt)

c=======================================================================
c     herbs and shrubs
c=======================================================================
      
      call solar_trees(ngt)

      nstrate = 1
      ipi = 1
      ipf = nherb+nbush

c=======================================================================
c     limits the lai according to water fluxes.. CARAIB and IBM have to 
c     be coherent
c=======================================================================

      call wat_limit

c=======================================================================
c     carbon fluxes calulation
c=======================================================================

      call year_iteration(ngt,itmt,tmt_it)

      call lai_limit_w

      if (ifrac.eq.1 .and. ny0.eq.1 .and. nyear.eq.1 .and. iread.eq.0
     &   .and. ifrac_rd.eq.0) 
     &   call frac_herbs(ngt)

c=======================================================================
c   yearly gpp and fractionation calculation
c=======================================================================
      do ip = 1,npft      
        if(frac(ip).gt.1.e-7) then
          do iday = 1, nd
            ygppf(ip) = ygppf(ip) + xgpp(ip,iday)
            yfractf(ip) = yfractf(ip) + xfract(ip,iday)
          enddo
          if (ygppf(ip).eq.0.) then 
            yfractf(ip) = 0. 
          else
            yfractf(ip) = yfractf(ip) / ygppf(ip)
          endif
        endif
      end do
      

c=======================================================================
c      fire module
c=======================================================================

      call fire(ngt)

c=======================================================================
c      mortality calculation
c=======================================================================

      call mortality(ngt)

c=======================================================================
c      biomass correction module
c=======================================================================

      call biomass_correction 



c=======================================================================
c   grid point gpp, npp, lai, biomass, 13C fract and fire emission
c=======================================================================

      do iday = 1, nd
        do ip = 1, npft
          xdgpp(iday) = xdgpp(iday) + frac(ip) * xgpp(ip,iday)
          xdnpp(iday) = xdnpp(iday) + frac(ip) * xnpp(ip,iday)
          xdlai(iday) = xdlai(iday) + frac(ip) * xlai(ip,iday)
          xdfract(iday) = xdfract(iday) 
     &                              + frac(ip) * xfract(ip,iday)
          do ipool = 1, npool 
           xdbiom(iday) = xdbiom(iday) + frac(ip)*carbon(ip,ipool,iday)   
           ybiomf(ip) = ybiomf(ip) + carbon(ip,ipool,iday)/float(nd)
	   xemifire(ip,iday) = xemifire(ip,iday)
     &                       + emi_burn_veg(ip,ipool,iday)
	   xcharvest(ip,iday) = xcharvest(ip,iday)
     &                       + charvest(ip,ipool,iday)     
           yemifiref(ip) = yemifiref(ip) + emi_burn_veg(ip,ipool,iday)
          enddo
        enddo

        if(xdgpp(iday).ne.0.) then
          xdfract(iday) = xdfract(iday) / xdgpp(iday)
        else
          if(abs(xdfract(iday)).gt.1.e-20) then
            write(61,*) 'error, fractionation:',iday,xdfract(iday),
     &                  xdgpp(iday)
          endif
	  xdfract(iday) = 0.
        endif

      enddo

c=======================================================================
c    vegetation fraction calculation. It is used to normalize FAPAR
c=======================================================================

      tot_frac = 0.
      do ip = 1, npft
        tot_frac = tot_frac + frac(ip)
      end do

c      write(*,*)'npp_cal:after loop iday,ip, ybiom'
c=======================================================================
c   fapar calculation
c=======================================================================

      do iday = 1, nd
       xdfapar(iday) = 0.
       if(partoc(iday).gt.0.) then
         do ip = 1, npft
           faparl = 0.
           if(frac(ip) .gt. 1.e-7) then
             do ih = 1, nh2
               faparh = 0.

                 faparh = faparh
     &   + (sunhour(iday) * (fsun(ip,iday,ih)*apar(ip,iday,ih,1)
     &   + (1.-fsun(ip,iday,ih))*apar(ip,iday,ih,2))
     &   + (1.-sunhour(iday)) * apar(ip,iday,ih,3))
     &   *corr_hour(iday,ih)/radun

               faparl = faparl + faparh
             enddo
             faparl = faparl * xlai(ip,iday) * frac(ip)
           endif
           xdfapar(iday) = xdfapar(iday) + faparl
         enddo
         xdfapar(iday) = xdfapar(iday) / partoc(iday)

         if(tot_frac.gt.0.0) then
           xdfapar(iday)= xdfapar(iday) / tot_frac
         endif
       endif
       if(xdfapar(iday).lt.0. .or. xdfapar(iday).gt.1.) then
         write(61,*) 'error L',iday,xdfapar(iday)
       endif
      enddo

c      write(*,*)'npp_cal:after loop iday fapar'

c=======================================================================
c   calculation of g*Ca and g*Ci
c=======================================================================

      do iday = 1, nd
        do ip = 1, npft

            xdgca(iday) = xdgca(iday) 
     &                  + gca(ip,iday) * xlai(ip,iday) * frac(ip)
            xdgci(iday) = xdgci(iday) 
     &                  + gci(ip,iday) * xlai(ip,iday) * frac(ip)
        enddo
      enddo

c      write(*,*)'npp_cal: end of subroutine'


      return
      end

c=======================================================================
c***********************************************************************
      subroutine wat_limit
c***********************************************************************
c=======================================================================  
      implicit none
c=======================================================================
c     This routine determinates the maximum lai when soil water is 
c     missing. Behaviour is different for grasses, evergreen, cold
c     deciduous or warm deciduous trees
c=======================================================================
 
      include './com_18/parameter.common'
      include './com_18/annee.common'
      include './com_18/bagnum.common'
      include './com_18/carbon_maxi.common'
      include './com_18/ecoin.common'
      include './com_18/lai.common'
      include './com_18/laih2o.common'
      include './com_18/lailim.common'
      include './com_18/loop.common'
      include './com_18/monthcst.common'
      include './com_18/nspc.common'
      include './com_18/pho_sch.common'
c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer m
      real*4 ylailim

c-----------------------------------------------

      do ip = ipi, ipf
       if(frac(ip).gt.1.e-7)then

        xleaf_max(ip) = 0.
        ylailim = 0.
        if (ip.gt.nherb) then
         if (idec(ip).eq.0) then
          ylailim=yminlai_w(ip)+0.4*(yvslai_w(ip)-yminlai_w(ip))         
c          ylailim=yminlai_w(ip)+0.8*(yvslai_w(ip)-yminlai_w(ip))
         elseif (idec(ip).eq.1) then
          ylailim=yminlai_w(ip)+0.4*(yvslai_w(ip)-yminlai_w(ip))
c          ylailim=yminlai_w(ip)+0.8*(yvslai_w(ip)-yminlai_w(ip))
         endif
         if(ylailim.lt.yminlai_w(ip)) ylailim = yminlai_w(ip)
        endif
        do m = 1, nm
         if (ip.le.nherb) then
          ylailim= xlai_w(ip,m)
         elseif (idec(ip).eq.2) then
          ylailim=yminlai_w(ip)+0.4*(xlai_w(ip,m)-yminlai_w(ip))
c          ylailim=yminlai_w(ip)+0.8*(xlai_w(ip,m)-yminlai_w(ip))         
          if(ylailim.lt.yminlai_w(ip)) ylailim = yminlai_w(ip)
         endif

         if(nyr_t2.eq.1) ylailim = ylailim0(ip,m)
  
         ylailim0(ip,m) = ylailim
 
         do iday = ini(m),ifin(m)
          carb_max0(ip,iday) = ylailim / splai(ip)
         end do
        end do 
       endif
      enddo

      return
      end

c=======================================================================
c***********************************************************************
      subroutine year_iteration(ngt,itmt,tmt_it)
c***********************************************************************
c=======================================================================
      implicit none
      
      include './com_18/parameter.common'      
      include './com_18/annee.common'
      include './com_18/annppf.common'
      include './com_18/bagnum.common'
      include './com_18/carbon_maxi.common'
      include './com_18/cmoiRmin.common'
      include './com_18/crops.common'
      include './com_18/cte.common'
      include './com_18/ecoin.common'
      include './com_18/ext_con2.common'
      include './com_18/gcaci2.common'
      include './com_18/gk.common'
      include './com_18/init.common'
      include './com_18/iprt.common'      
      include './com_18/lai.common'
      include './com_18/laiste.common'
      include './com_18/litiere.common'
      include './com_18/loop.common'
      include './com_18/management.common'      
      include './com_18/mois.common'
      include './com_18/number_year.common'
      include './com_18/nspc.common'
      include './com_18/pho_sch.common'      
      include './com_18/plant_evol.common'
      include './com_18/plant_pool.common'
      include './com_18/pnpp2.common'
      include './com_18/prev_yr.common'      
      include './com_18/res_temp2.common'
      include './com_18/tresh.common'
      include './com_18/xvalues.common'


      integer iday_sow
      
      real*4 dorm_rfac,rbmax,rem_harvbio,xlit_harvbio,rbudget,carb_sup    

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt, itmt
      real*4  , intent(in) :: tmt_it
      
      integer iday2,ipool
      
      real*4 carb_max,d_leaf_max,Fin,Fin0,gk1,gk2,gk2_dorm,gk3
      real*4 gk3max,gknew,gktot,grow_fac,h_res,resp_frac,s,test_grow,
     &      w_min,wminfac,wminfacm1,xf1,xf2 
c-----------------------------------------------

      dimension gktot(npool),Fin0(npool),Fin(npool),gk2(npool),
     &          gk1(npool),
     &          resp_frac(npool),w_min(nplant)
     
     
      do ip = ipi,ipf
       
       ynppf(ip) = 0.
       
       ybinc(ip) = 0.
       
       if(frac(ip).gt.1.e-7) then
        
	iday_sow = int(sow_date(ip))
	
        do iday = 1, nd
	
          if (iday.eq.1) then

            w_min(ip) = rese(ip) 
cfv     &                + (rese(ip)/xip(ip,1))**(1./xkappa(ip))
            if(iday_sow.gt.0) w_min(ip) = carb_init(ip,2)


            xlai_max(ip) = 0.
            xlai_min(ip) = 100. 
            xlai_moy(ip) = 0.

          endif

          iday2 = iday - 1
          if(iday .eq. 1) iday2 = nd
          if(iday .eq. iday_sow) then
            do ipool = 1, npool
              carbon(ip,ipool,iday2) = carb_init(ip,ipool)
            end do
            rese(ip) = carbon(ip,2,iday2)
          endif
          if(rese(ip).gt.carbon(ip,2,iday2)) rese(ip) 
     &                                       = carbon(ip,2,iday2)
        
          xgpp(ip,iday)   = 0. 
          xnpp(ip,iday)   = 0.
          xlrm(ip,iday)   = 0.
          xfract(ip,iday) = 0.
          xlai(ip,iday)   = carbon(ip,1,iday2) * splai(ip)

          if (xlai(ip,iday).lt.xlai_min(ip)) xlai_min(ip) =
     &                                       xlai(ip,iday)
          if (xlai(ip,iday).gt.xlai_max(ip)) xlai_max(ip) =
     &                                       xlai(ip,iday) 
          xlai_moy(ip) = xlai_moy(ip) + xlai(ip,iday)

c=======================================================================
c   gpp calculation:
c
c   gpp   = sum over LAI of leaf layer gpp;
c   splai = specific leaf area (m2 gC-1).
c=======================================================================

c-----------------------------------------------------------------------
          if(xlai(ip,iday).gt.0.) call solar_flux
          
          if(itmt.eq.0.or.
     &           (nyear.eq.1.or.tmt_it.eq.itmt.or.ip.eq.isp)) then
          
          call gpp_cal(ngt)
          
          endif  
          
c         if(itmt.ne.0) then      
          
c           do ipool = 1, npool
c              resp_fac(ip,ipool,iday) = 
c     &                        resp_fac_temp(ip,ipool,iday,ngt)
c            enddo

c            gca(ip,iday) = gca_temp(ip,iday,ngt) 
c            gci(ip,iday) = gci_temp(ip,iday,ngt)
 
c            zgpp(ip,iday) = zgpp_temp(ip,iday,ngt)

c            zfract(ip,iday) = zfract_temp(ip,iday,ngt)
c            zfh2o(ip,iday)  = zfh2o_temp(ip,iday,ngt)
            
c         endif 
          
c-----------------------------------------------------------------------

          xgpp(ip,iday) = xgpp(ip,iday)  + zgpp(ip,iday) * xlai(ip,iday)
          xfract(ip,iday) = xfract(ip,iday)  
     &                    + zfract(ip,iday) * xlai(ip,iday)

c=======================================================================
c   determination of pool decrease factor, ktot (d-1):
c      ktot = k1 + k2 + k3
c      where k1 = respiration factor;
c            k2 = litter production factor;
c            k3 = factor describing biomass tranfer from reserves to 
c                 "green" pool.
c
c   xnpp = daily npp.
c=======================================================================

          resp_frac(1) = 1.
          resp_frac(2) = 1.

          if (ip.gt.nherb .and. carbon(ip,2,iday2).gt.0.) then
            resp_frac(2) = xip(ip,2)
     &                   * (carbon(ip,2,iday2)**(xkappa(ip)-1.)) 
            if (resp_frac(2).gt.1.) resp_frac(2) = 1.
          endif
	  
          if((idec(ip).eq.2).and.(xlai(ip,iday).le.0.01))then
	        dorm_rfac = 0.1
	      else
	        dorm_rfac = 1.
	  endif	  
	  

          do ipool = 1, npool
            gk1(ipool) = gk1_25(ip,ipool) * resp_frac(ipool)
     &                 * resp_fac(ip,ipool,iday)*dorm_rfac
            
            if(ipool.eq.1) then
              gk2(ipool) = gk_fall(ip,ipool,1)	    
              if (
     &            water2(iday) .le. wattresh1(ip)) then !.or.
c     &            xpar2(iday)  .le. xpar_tresh1(ip) .or.
c     &            iphase(ip,iday) .eq. 2) then
                gk2(ipool) = gk_fall(ip,ipool,2)
              endif       
              if (tmin2(iday)  .le. ttreshi1(ip)  .or.
c     &            tmax2(iday)  .ge. ttresha1(ip)  .or.	      
     &            xpar2(iday)  .le. xpar_tresh1(ip)) then !.or.
charv     &            iphase(ip,iday) .eq. 2) then
                 gk2(ipool) = gk_fall(ip,ipool,3)
              endif
            elseif (ipool.eq.2) then
	        gk2(ipool) = 0.
cb              if (tmin2(iday)  .le. ttreshi2(ip)  .or.
c     &            tmax2(iday)  .ge. ttresha2(ip)  .or.
cb     &            water2(iday) .le. wattresh2(ip) .or.
cb     &            xpar2(iday)  .le. xpar_tresh2(ip)  .or.
cb     &            iphase(ip,iday).eq.2) then
charv              if(iphase(ip,iday).eq.2) then
charv                gk2(ipool) = gk_fall(ip,ipool,3)
charv              endif
            endif
          enddo

          gk2_dorm = 0.2 / 365.
          if (carbon(ip,2,iday2).le.w_min(ip) .and. 
     &        iphase(ip,iday).ne.2) then
            gk1(2) = 0.
            gk2(2) = 0.   !gk2_dorm
          endif

          wminfac = 1.5
          wminfacm1 = wminfac - 1.
          if (carbon(ip,2,iday2).lt.wminfac*w_min(ip).and.
     &        carbon(ip,2,iday2).gt.w_min(ip) .and.
     &        iphase(ip,iday).ne.2) then
            xf1 = carbon(ip,2,iday2) - w_min(ip)
            xf2 = wminfac * w_min(ip) - carbon(ip,2,iday2)
            gk1(2) = gk1(2) * xf1 / (wminfacm1 * w_min(ip))
c            gk2(2) = (gk2(2)*xf1 + xf2*gk2_dorm) / (wminfacm1*w_min(ip))
            gk2(2) = 0.
          endif
              
          do ipool = 1, npool
            gktot(ipool) = gk1(ipool) + gk2(ipool)
            xlit_prod(ip,ipool,iday) = gk2(ipool) 
     &                               * carbon(ip,ipool,iday2)
          enddo

c=======================================================================
c   phenology:
c
c   S is a phenological parameter. It determine the fraction
c   of the gross primary productivity allocated to leaves and fine roots.
c
c   S = 0 during cold or warm period;
c   S = rootf during the growing season;
c   S = Smax during the rest of the year, limiting the green carbon
c       pool to a maximum function of the wood biomass.
c=======================================================================

          S    = 0.
          gk3  = 0.
          carb_max = 0.


          if (tmin2(iday)     .gt. ttreshi1(ip)    .and.
c     &        tmax2(iday)     .lt. ttresha1(ip)    .and.
     &        water2(iday)    .gt. wattresh1(ip)   .and.
     &        xpar2(iday)     .gt. xpar_tresh1(ip).and.
     &        iphase(ip,iday) .eq. 1) then
            carb_sup = xlaisup(ip)/splai(ip)     
            if (ip.le.npft0) then
              carb_max = xip(ip,1) *
     &                 (carbon(ip,2,iday2)**xkappa(ip))
              if (carb_max.gt.carb_sup) carb_max=carb_sup     
            else
              carb_max = carb_sup
            endif
            if(carb_max.lt.rese(ip)) carb_max = rese(ip)
            gknew = gktot(1)
            if (carb_max.gt.carb_max0(ip,iday)) then
              if (carbon(ip,1,iday2).le.carb_max0(ip,iday)) then 
                carb_max = carb_max0(ip,iday)
              else
                carb_max = carbon(ip,1,iday2)
              endif
              gknew    = gk1(1)
            endif
            d_leaf_max = (carb_max - carbon(ip,1,iday2))/(1-h_grow) 
     &                 + gknew*carbon(ip,1,iday2)
            if (d_leaf_max .lt. 0.) d_leaf_max = 0.
            if (xgpp(ip,iday).gt.0.) S = d_leaf_max / xgpp(ip,iday)
            if (xgpp(ip,iday).eq.0.) S = 1.
            if (S .lt. 0.)           S = 0.
            if (S .gt. rootf(ip))    S = rootf(ip)
            if (S.eq.rootf(ip) .and. rese(ip).gt.0.) then
              gk3max = gkboom(ip)
              if (carbon(ip,1,iday2).lt.carb_max .and.
     &            carbon(ip,1,iday2).lt.rese(ip)) then
                gk3max = (d_leaf_max - S * xgpp(ip,iday))/ rese(ip)
                if(gk3max.lt.0.) then
                  gk3max = 0.
                endif
                gk3  = gkboom(ip)
                if(gk3.gt.gk3max) gk3 = gk3max
              endif
            endif
          endif

c=======================================================================
c     incoming fluxes
c=======================================================================

          Fin0(1) = S * xgpp(ip,iday) 
          Fin0(2) = (1. - S) * xgpp(ip,iday)
          Fin(1)  = Fin0(1) + gk3 * rese(ip)
          Fin(2)  = Fin0(2)

	  

c=======================================================================
c     management control (for management cuts)
c=======================================================================

          if (imanag.eq. 1) then
            icut = 0
            do ict = 1, mg_days(ip)
             if (iday_mg(ip,ict).eq.iday) icut = ict
            end do
          endif
          
c=======================================================================
c      pools calculation
c=======================================================================
c      write(*,*)'year_iteration:before ipool=1,npool, if carbon ...'

          do ipool = 1, npool

            if (carbon(ip,ipool,iday2).lt.0.) then
              write(61,*) iyear(ip),iday,ip,ipool,
     &                    carbon(ip,ipool,iday2) 
              stop
            endif
            if (Fin(ipool).lt.0.) Fin(ipool) = 0.
            if (ipool.eq.1) then
              xlrm(ip,iday) = xlrm(ip,iday)+gk1(ipool)
     &                      * carbon(ip,ipool,iday2)
            endif 
            h_res = 0.
            test_grow = gk1(ipool) * carbon(ip,ipool,iday2)
            if (ipool.eq.2) test_grow = test_grow + gk3 * rese(ip)
            if (Fin(ipool) .gt. test_grow) h_res = h_grow
            grow_fac = 1. - h_res
            Fin(ipool) = Fin(ipool) * grow_fac

            gktot(ipool) = gk1(ipool) * grow_fac
            if (ipool.eq.2 .and. carbon(ip,ipool,iday2).ne.0.)
     &        gktot(ipool) = gktot(ipool) 
     &                     + gk3*rese(ip)/carbon(ip,ipool,iday2)
            xnpp(ip,iday) = xnpp(ip,iday) + Fin(ipool)
     &                    - gktot(ipool)*carbon(ip,ipool,iday2)

            gktot(ipool) = gktot(ipool) + gk2(ipool)

c=======================================================================
c   Reservoir budget and update of carbon biomass pool
c=======================================================================     
     
            rbudget = Fin(ipool) - gktot(ipool)*carbon(ip,ipool,iday2)    
	    
            carbon(ip,ipool,iday) = carbon(ip,ipool,iday2) + rbudget


c=======================================================================
c   Biomass increment for species longevity calculation
c=======================================================================     
     
            ybinc(ip) = ybinc(ip)+ rbudget      
     
	    
c=======================================================================      
c   Estimation of PFT root biomass per m2 of presence (g C m-2)
c     rootsh = root:shoot ratio (from Mokani et al., Global Change Biol
c                               12, 84-96, 2006) 
c     root_biomass = root biomass (gC m-2)
c=======================================================================
            if (ipool.eq.2)then
             rbmax = (rootsh(ip)/(1.+rootsh(ip)))
     &                 *(carbon(ip,1,iday)+carbon(ip,2,iday))
             root_biomass(ip,iday) = min(carbon(ip,2,iday),rbmax)
	        endif

c=======================================================================            
c  Management calculation
c        fcut = fraction of reservoir cut
c=======================================================================            
            fcut = 0.
            
            if ((imanag.eq.1).and.(icut.ne.0)) then
	     if (mg_mode(ip).eq.0) then
c             no management	     
	     endif
             if (mg_mode(ip).eq.1) then
c             reservoir 1: LAI is reduced to value stored in cleft_mg    
              if((ipool.eq.1).and.(carbon(ip,1,iday).gt.1.e-10)) fcut = 
     &          1.-((cleft_mg(ip,1,icut)/splai(ip))/carbon(ip,1,iday))
c             reservoir 2: aboveground carbon is reduced to value stored  
c                          in cleft_mg
c                          belowground fraction is calculated from 
c                          root:shoot ratio rootsh(ip)      
              if((ipool.eq.2).and.(carbon(ip,2,iday).gt.1.e-5)) fcut = 
     &          1.-((cleft_mg(ip,2,icut)+root_biomass(ip,iday))
     &         /carbon(ip,2,iday))
              if (fcut.lt.0.) fcut = 0. 
              if (fcut.gt.1.) fcut = 1.     
             endif
             if (mg_mode(ip).eq.2) then
c             reservoir 1 & 2: cleft_mg = biomass reduction factor in %     
              if(carbon(ip,ipool,iday).gt.1.e-5) fcut = 
     &          1.-(cleft_mg(ip,ipool,icut)/100.)
              if (fcut.lt.0.) fcut = 0. 
              if (fcut.gt.1.) fcut = 1.     
             endif	     
            endif
c=======================================================================
c     crop harvested biomass 
c=======================================================================
            rem_harvbio = 0.
	    xlit_harvbio = 0.
	    
         if(iphase(ip,iday).eq.2) then
	    
c     crop is harvested not cut  => remove any possible management cut 	    
	      fcut = 0.

c     rem_harvbio = harvested biomass removed from site	      
	      if (ipool.eq.1) then
	         rem_harvbio = fL_harv(ip)*carbon(ip,1,iday)
	      endif 	      
	      if (ipool.eq.2) then
	         rem_harvbio = fR_harv(ip)*root_biomass(ip,iday)
     &            +fS_harv(ip)*(carbon(ip,2,iday)-root_biomass(ip,iday))
          endif

c     xlit_harvbio = harvested biomass transferred to litter	      
              xlit_harvbio = carbon(ip,ipool,iday)- rem_harvbio
	      
	     endif	    
c=======================================================================

	    
c      charvest= harvested or (management) cut biomass removed from site
c	    
            charvest(ip,ipool,iday) = fcut*carbon(ip,ipool,iday)
     &                      + rem_harvbio
            carbon(ip,ipool,iday) = carbon(ip,ipool,iday) 
     &                      - charvest(ip,ipool,iday) - xlit_harvbio     
            ycharvest(ip) = ycharvest(ip) + charvest(ip,ipool,iday)
	    
	    xlit_prod(ip,ipool,iday) = xlit_prod(ip,ipool,iday)
     &                      + xlit_harvbio
	    
            if (carbon(ip,ipool,iday).lt.0.01) then
              xlit_prod(ip,ipool,iday) = 
     &        xlit_prod(ip,ipool,iday) +
     &        carbon(ip,ipool,iday)
              carbon(ip,ipool,iday) = 0.
            endif	    
	    
	    
          enddo             ! end do ipool

 2323    format(i6,2(1x,f8.2))
c      write(*,*)'year_iteration:befor if(carbon(ip...xleaf_max'

          if(carbon(ip,1,iday).gt.xleaf_max(ip))
     &      xleaf_max(ip) = carbon(ip,1,iday)
          if(rese(ip).gt.carbon(ip,2,iday))
     &      rese(ip) = carbon(ip,2,iday)


          if (iday.eq.nd) then

cmoi----Rmin------------------------------------------------------------
            if (xlai_max(ip).ne.0.) then 
              R_min(ip) = xlai_min(ip) / xlai_max(ip)
            else
              R_min(ip) = 0.
            endif
            xlai_moy(ip) = xlai_moy(ip) / float(nd)
cmoi----Rmin------------------------------------------------------------

            rese(ip) = rese_frac(ip) * xleaf_max(ip)

          endif
  
          ynppf(ip) = ynppf(ip) + xnpp(ip,iday)

        end do    ! end do iday
       endif
       if(ynppf(ip).lt.0.) ynppf(ip) = 0.
       ynppf_grd(ip,ngt) = ynppf(ip)
              
              
      end do      ! end do ip

      return
      end

c=======================================================================
c***********************************************************************
      subroutine solar_flux
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c   calculation of the radiative transfer within the canopy.
c   clump_fac = clumping factor
c=======================================================================
      include './com_18/parameter.common'
      include './com_18/ext_con.common'
      include './com_18/loop.common'
      include './com_18/radcst.common'
      include './com_18/sol_in.common'
      include './com_18/strate.common'
      include './com_18/xvalues.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer ih
      
      real*4 atte,attedif,attedir1,attedir2
      real*4 facgk,facpk,facpkdif,fsun_toc
      real*4 gk,pk,pkdif,rhoc
      

c------------------------------------------------      
      do ih = 1,nh2

        attedir1 = 0.
        attedir2 = 0.
        attedif  = 0.
        fsun(ip,iday,ih) = 1.

        if(xmucar(iday,ih) .ne. 0.) then

          gk  = clump_fac * 0.5 / xmucar(iday,ih)
          facgk = - gk * xlai(ip,iday) / 2.
          if(facgk .lt. -40.) facgk = -40.

          fsun_toc   = 1.
          if(nstrate.eq.1) fsun_toc = fsun0(iday,ih)
          fsun(ip,iday,ih) = fsun_toc * exp(facgk)
          fsun(ip,iday,ih) = 0.01*int(0.49 + 100.*fsun(ip,iday,ih))
          if(fsun(ip,iday,ih).gt.1..or.fsun(ip,iday,ih).lt.0.) then
            write(61,*) 'error sun/shade',fsun(ip,iday,ih)
            stop
          endif 

          attedir1 = (1- ome) * gk
          pk    = facome * gk
          rhoc  = (2 / (1. + 1.6 *xmucar(iday,ih))) * rhoc0

          facpk = -pk    * xlai(ip,iday) / 2.
          if(facpk .lt. -40.) facpk = -40.
          atte  = exp(facpk) * pk * (1 - rhoc)
          attedir2 = (atte -  fsun(ip,iday,ih) * attedir1)
          if(attedir2.lt.0.) then
            attedir2 = 0.
            attedir1 = atte/fsun(ip,iday,ih)
          endif

          pkdif = 0.8 * facome
          facpkdif = -pkdif    * xlai(ip,iday) / 2.
          if(facpkdif .lt. -40.) facpkdif = -40.
          attedif  = exp(facpkdif) * pkdif * (1. - rhoc0)

        endif

        if(nstrate.eq.0) then
          apar(ip,iday,ih,1) = radun * 
     &                        ((attedir1+attedir2)*par0(iday,ih,1) 
     &                        + attedif*par0(iday,ih,2))
          apar(ip,iday,ih,2) = radun * 
     &          (attedir2*par0(iday,ih,1) + attedif*par0(iday,ih,2))
          apar(ip,iday,ih,3) = radun * attedif * par0(iday,ih,3)
        else
          apar(ip,iday,ih,1) = radun * 
     &                        ((attedir1+attedir2)*par1(iday,ih,1) 
     &                        + attedif*par1(iday,ih,2))
          apar(ip,iday,ih,2) = radun * 
     &          (attedir2*par1(iday,ih,1) + attedif*par1(iday,ih,2))
          apar(ip,iday,ih,3) = radun * attedif * par1(iday,ih,3)
        endif

      enddo

      return
      end
 
c=======================================================================
c***********************************************************************
      subroutine gpp_cal(ngt)
c***********************************************************************
c=======================================================================

c=======================================================================
c
c     this routine calculates the co2 net assimilation by leaves
c
c     output: xgpp  : leaf gross primary productivity (gC m-2 d-1 for
c                     an leaf layer).
c
c=======================================================================
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/acclim.common'
      include './com_18/climin0.common'
      include './com_18/climin.common'
      include './com_18/coord.common'
      include './com_18/cstpi.common'
      include './com_18/c3cst.common'
      include './com_18/c3en.common'
      include './com_18/c4cst.common'
      include './com_18/cte.common'
      include './com_18/day_corr.common'
      include './com_18/deltac13.common'
      include './com_18/down_reg.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/envi.common'
      include './com_18/ext_con.common'
      include './com_18/ext_con2.common'
      include './com_18/gcaci2.common'
      include './com_18/h2ocst.common'
      include './com_18/lai.common'
      include './com_18/laih2o.common'
      include './com_18/laiste.common'
      include './com_18/loop.common'
      include './com_18/monthcst.common'
      include './com_18/nspc.common'
      include './com_18/pho_sch.common'
      include './com_18/pnpp2.common'
      include './com_18/monwat.common'
      include './com_18/rblcst1.common'
      include './com_18/res_par.common'
      include './com_18/res_temp2.common'
      include './com_18/snow.common'
      include './com_18/temper.common'
      include './com_18/tresh.common'
      include './com_18/varday.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt


      integer ipool,ih,irad
      
      real*4 a0,a1,b,b1,b2,beta0
      real*4 c,c1,c2,co2cl,coeffs
      real*4 d,f00,fac,fac0,fac1,fac2,fac02,fac04,fac05
      real*4 fac23,fac3,fac4,fac5,fac6,fac7,fac8,fac34,fac35
      real*4 facgj,facgjm,factt,factt2,farbl,fard,fkt0,fkt3
      real*4 fkt4,fkt5,fracth,fs,fh2o_mth,g1new
      real*4 gamet,gj,gjm0,gjmax,gkc,gko
      real*4 gn,gn0,gn1,gn2,gn3,gnd,gst
      real*4 pkc,pko,q,r,rd,rd0,rd34
      real*4 rbl04,rbl05,rd35,rdfac,rho1,rho2,roo,rtot
      real*4 rto,s,sqrtq,tdep,test,test1,test2,tfact
      real*4 tfacto,theta0,unitchg,vcm00,vcmax,vt0,wat_eff
      real*4 xkt,xkt0,rtot_w,test0
      
c-----------------------------------------------
    
      dimension gn2(3),gnd(3),g1new(ndy,nplant),fh2o_mth(nm)
      real*4 co2past,xco2,x365,x567,rfac_CO2,rvcm,rjm,rrd
      real*4 tempast,rdaccl,tempast_m,rdaccl_f
      real*4 spaccl,spaccl_f      
      integer iy_past,maxyr,m,m_past,maxmth,k

      character*100 formatw,formaty



c=======================================================================
c     initialisation
c=======================================================================

      do ipool = 1, npool
        resp_fac(ip,ipool,iday) = 0.
      enddo

      gca(ip,iday) = 0.
      gci(ip,iday) = 0.
c-----------------------------------------------------------------------
      zgpp(ip,iday)   = 0.
CNPP            znpp(ip,iday)   = 0.
      zfract(ip,iday) = 0.
      zfh2o(ip,iday)  = 0.
c-----------------------------------------------------------------------

c======================================================================		
c      downregulation of vcmax and jmax (FACE data)
c        rvcm = downregulation factor for Vcmax
c        rjm = downregulation factor for Jmax 
c        rrd = downregulation factor for Rd
c        CO2 is averaged over the last N years (N=maxyr, 
c                                                with maxyr+1<20) 
c======================================================================

      if (jdwnCO2.ge.1) then
        co2past = 0.
        maxyr = 4
        do iy_past = 2, maxyr+1
         co2past = co2past + co2_prev(iy_past)/float(maxyr)
        end do 
        xco2 = co2past/(co2past+gkc3)
        x365 = 365./(365.+gkc3)
        x567 = 567./(567.+gkc3)
        rfac_CO2 = (xco2-x365)/(x567-x365)  
        rvcm = 1. + (rvcm567(ip)-1.)*rfac_CO2
        if (rvcm.le.0.1) rvcm = 0.1
        rjm = 1. + (rjm567(ip)-1.)*rfac_CO2
        if (rjm.le.0.1) rjm = 0.1
        if (jdwnCO2.eq.1) then
         rrd = rvcm
        else
         rrd = 1.
        endif   
      else
        rvcm = 1.
        rjm = 1.
        rrd = 1.
      endif

c======================================================================		
c      acclimation of leaf respiration to temperature
c        jrd_accl = 0/1/2 
c         0 : No acclimation
c         1 : long-term (several years) acclimation for all plant parts 
c         2 : mid-term (several months) acclimation for leaves
c             and long-term (several years) acclimation for structural
c             parts
c        
c        rdsurvc = Rd/Vcmax = assumed to respond to temperature of the 
c                  previous years - decreases at higher temperatures
c        tempast = mean temperature of the N previous years (N=maxyr, 
c                               with maxyr+1.le.5) (long-term)
c        tempast_m = mean temperature of the N previous months 
c                     (N=maxmth, with maxmth<12)   (mid-term)
c        rdaccl = temperature acclimation factor for structural parts
c        rdaccl_f = temperature acclimation factor for leaves        
c======================================================================		

      if (jrd_accl.eq.0) then
        rdaccl = 1.
	rdaccl_f = 1.
        rdsurvc = rdsurvc0
      else      
        tempast = 0.
        maxyr = 4
        do iy_past = 2, maxyr+1
         tempast = tempast + ytem_prev(ngt,iy_past)/float(maxyr)
        end do
c  adapted from Wythers et al., GCB, 11, 435-449, 2005
c      rdaccl = normalized ratio = (0.14 - 0.002*tcel)/0.09
c            with 0.09 the value of the bracket term at 25°C 	 
        rdaccl=1.5556-0.0222*tempast
	rdsurvc = rdsurvc0 
        if (jrd_accl.eq.1) then
	  rdaccl_f = rdaccl
	else 
	  m = imonth(iday)
	  tempast_m = 0.
	  maxmth = 2
	  do k = 1, maxmth
	   m_past = m-k
	   if (m_past.le.0) then
	    tempast_m = tempast_m+py_mtem(ngt,m_past+nm)/float(maxmth)
	   else
	    tempast_m = tempast_m+tcel0(m_past)/float(maxmth)
	   endif
	  end do 
	  rdaccl_f = 1.5556-0.0222*tempast_m
        endif
      endif 
        
c======================================================================
c      acclimation of leaf respiration to low values of specific
c      leaf area SLA (e.g., to limit respiration costs in dry climates)
c        spaccl = SLA acclimation factor for structural parts
c        spaccl_f = SLA acclimation factor for leaves
c======================================================================      
c      spaccl_f = min(splai(ip),0.025)/0.025  
c      spaccl = spaccl_f   
      spaccl_f = 1. 
      spaccl = 1.
  
c=======================================================================
c la resistance stomatique (pas g0 mais g1) a ete multipliee par 
c l'exponentielle de Wijk plottee sur Leuning

      wat_eff = (water(iday)-0.5*wattresh2(ip)) / (1.-0.5*wattresh2(ip))
      if (wat_eff.lt.0.) wat_eff=0.
      fs = 1.-0.016572*exp(4.1*(1.-wat_eff))

      g1new(iday,ip) = g1(ip) * fs

c=======================================================================
c   beginning of the calculation:
c   g0     = intercept for the stomatal conductance;
c   g1     = slope for the stomatal conductance;
c   temp  = temperature in k;
c   gjmax = light potential rate of electron tranport on area basis
c           (mueq m-2 s-1);
c   gj    = potential rate of electron transport on area basis
c           (mueq m-2 s-1);
c   apar   = solar irradiance (micromol photons/(m2 s));
c   ea    = activation energy used to calculate the temperature
c           dependance of a paramater(j mlo-1);
c   gkc   = michaelis constant for co2 (mubar);
c   gko   = michaelis constant for o2 (mbar);
c   pkc   = turnover number of rup2 carboxylase (s-1);
c   pko   = turnover number of rup2 oxygenase (s-1);
c   vcmax = maximum carboxylation velocity (mumol m-2 s-1);
c   gamet = co2 compensation point without dark respiration (mubar);
c   rd   = dark respiration (mumol m-2 s-1);
c   co2a = atmospheric partial pressure of co2 (mubar);
c   hs     = air relative humidity;
c   o2cl   = partial pressure of o2;
c   rbl    = boundary layer resistance (mol m-2 s-1).
c=======================================================================

c=======================================================================
c   C4 parameters:
c 
c   vc4     = rubisco capacity (mumol m-2 s-1);
c   xkt    = initial slope of the photosynthetic co2 response 
c            (mol m-2 s-1).
c=======================================================================

c=======================================================================
c   loops over the hours
c=======================================================================

        do ih = 1, nh2
c no photosynthesis below -10 oC    (-4 oC in earlier version)  
          if(temp(iday,ih).ge.(temp0-10.)) then

c=======================================================================
c   C3 plants temperature dependence of Rd (tfacto)
c=======================================================================

            tdep  = (temp(iday,ih) - 298.15) / temp(iday,ih)
            tfact = exp(tdep * eapkc)
            gkc   = gkc3   * exp(tdep * eagkc)
            gko   = gko3   * exp(tdep * eagko)
            pkc   = pkc3   * tfact
            pko   = pkcko  * pkc
            gamet = gkc * o2cl * pko / (2 * gko * pkc)
            f00   = co2a - gamet
            test1 = f00 / (co2a + 2. * gamet)
            fac1  = gkc * (1. + o2cl/gko)
            facgj = 1. + exp((sjm*temp(iday,ih)-hjm)/temp(iday,ih))
            tfacto = tfact 

c=======================================================================
c    C4 plants temperature dependence of Rd (rd0)
c=======================================================================

            fac   = (temp(iday,ih) - 298.15) / 10. 
            factt  = 0.3 * temp(iday,ih)
            factt2 = 1.3 * temp(iday,ih)
            xkt0  = (q10**fac)
            vt0   = xkt0 
     &            / ((1+exp(fact0-factt)) * (1+exp(factt-fact1)))
            rdfac = factt2-fact2
            if(rdfac.lt.-40.) rdfac = -40.
            rd0   = xkt0 / (1. + exp(rdfac))
c=======================================================================
                if (ic4(ip).eq.1) then
                  resp_fac(ip,1,iday) = resp_fac(ip,1,iday) 
     &              + rd0*rrd*spaccl_f*rdaccl_f*(1.-snow_frac(iday))
                else
                  resp_fac(ip,1,iday) = resp_fac(ip,1,iday) 
     &              + rrd*spaccl_f*rdaccl_f*tfacto*(1.-snow_frac(iday))
                endif
                resp_fac(ip,2,iday) = resp_fac(ip,2,iday) 
     &              + rrd*spaccl*rdaccl*tfacto*(1.-snow_frac(iday))

                a1     = 1.6 / g0(ip) + rbl(ip,iday)
                fac0   = g1new(iday,ip) * hs(iday,ih) / co2a

                gn  = 0.
                gn0 = 0.
                gn1 = 0.
                gn3 = 0.

c======================================================================		
		
                vcm00  = vcm0(ip)*rvcm

                if (ic4(ip).eq.1) then

                  rd  = rd0 * rdsurvc * vcm0(ip)*rrd*spaccl_f*rdaccl_f 
                  xkt = xkt0 * xkc4
                  fkt0 = 1.6 * xkt
                  fkt3 = 1. + xkt * rbl(ip,iday)
                  fkt5 = xkt * a1
                  a0   = -fac0 * fkt3

                  test0 = xkt * co2a
c   test 1
c-----------------------------------------------------------------------
                  if(test0.gt.rd.and.a0.gt.0.) then
                    fac2  = g0(ip) - fac0 * rd
                    fac4  = co2a + rd * rbl(ip,iday)
                    fkt4 = xkt * fac4
                    b     = 0.5*( fkt4*fac0 - fac2*fkt3 - fkt0 )
                    c     =       fkt4*fac2 + fkt0*rd
                    roo   = b*b - a0*c
                    gn3 = -(b + sqrt(roo))/a0
                  else

c=======================================================================
c     limits the stomatal conductance to g0
c=======================================================================

                    gn3 = (xkt*co2a + rd*fkt5) / (1.+fkt5)
                  endif

                  gn1 = vcm00 * vt0 /2.

                else

                  vcmax = vcm00 * tfacto
                  rd    = rdsurvc*vcm0(ip)*rrd*spaccl_f*rdaccl_f*tfacto
                  a0    = rbl(ip,iday) * fac0
                  test0 = vcmax*f00 
     &                   / (co2a + gkc*(1.+o2cl/gko))
                  fac3 = -fac0 * rd + g0(ip)
                  fac4 = f00 + rd * rbl(ip,iday)
                  fac5 = fac4 + 3. * gamet
                  fac6 = co2a + rd * a1
                  fac7 = fac6 - gamet
                  fac8 = fac6 + 2. * gamet
                  fard = 1.6 * rd
                  farbl = 1.6 + rbl(ip,iday) * fac3
                  fac04 = fac0 * fac4
                  fac05 = fac0 * fac5
                  fac34 = fac3 * fac4
                  fac35 = fac3 * fac5
                  rbl04 = farbl - fac04
                  rbl05 = farbl - fac05
                  rd34  = fard + fac34
                  rd35  = fard + fac35

c=======================================================================
c   rubisco limitation
c=======================================================================

c   test2
c-----------------------------------------------------------------------

                  if(test0.gt.rd.and.a0.gt.0.) then

                    fac2 = co2a + fac1+ rd * rbl(ip,iday)
                    fac02 = fac0 * fac2
                    fac23 = fac2 * fac3

                    b  = ( (farbl - fac02)/a0 - vcmax )/3.
                    c  = - (vcmax*rbl04 + fac23 + fard)/a0
                    d  =   (vcmax*rd34)/a0

                    b2 = b*b
                    q  = b2 - c/3.
                    r  = b*(b2 - 0.5*c) + 0.5*d
                    sqrtq = sqrt(q)
                    coeffs = r /(sqrtq*q)

                    if(coeffs .lt. -1.) coeffs = -1.
                    if (coeffs.gt.1.) coeffs = 1.

                    s   = acos(coeffs)
                    gn1 = -2.*sqrtq*cos((4.*pi+s)/3.) - b 

                  else

c=======================================================================
c   limits the stomatal conductance to g0
c=======================================================================

                    b     = -0.5*(fac6 + vcmax*a1 + fac1)
                    c     =              vcmax*fac7
                    roo   = b*b - a1*c
                    gn1 = -(b + sqrt(roo))/a1

                  endif

                  gn3   = vcmax / 2.
c                  gjm0   = 1.67 * vcm0(ip) * rjm
                  gjm0   = 2.11 * vcm0(ip) * rjm 
                  gjmax  = gjm0 * exp(tdep * ejm) / facgj 
 
                endif

c=======================================================================
c   loops over the lai
c
c   an   = potential c3 net assimilation rate (micromol m-2 s-1);
c   gn   = potential c3 gross assimilation rate (micromol m-2 s-1).
c 
c   then;
c   sums the  values --> daily values for each lai step.
c=======================================================================

                  gn  = 0.
                  do irad = 1, 3
                    gn2(irad) = 0.
                  enddo
                  if (ic4(ip).eq.1) then 

c=======================================================================
c   irradiance limitation
c=======================================================================

                    do irad = 1, 3
                      gn2(irad) = alpc4 * apar(ip,iday,ih,irad) 
                    enddo

                  else

                    do irad = 1, 3

                      if(apar(ip,iday,ih,irad).gt.0.) then
                        facgjm = 2.1*gjmax + apar(ip,iday,ih,irad)
                        gj  = gjmax * apar(ip,iday,ih,irad)/facgjm
                        gj  = gj / 4.   
                        test2 = test1 * gj
c   test 3
c-----------------------------------------------------------------------
                        if(test2.gt.rd.and.a0.gt.0.) then

                          b = ( - gj       + rbl05/a0 )/3.
                          c =   -(gj*rbl04 + rd35)/a0
                          d =    (gj*rd34        )/a0

                          b2 = b*b
                          q  = b2 - c/3.
                          r  = b*(b2 - 0.5*c) + 0.5*d
                          sqrtq = sqrt(q)
                          coeffs = r /(sqrtq*q)
                          if(coeffs .lt. -1.) coeffs = -1.
                          if (coeffs.gt.1.) coeffs = 1.
                          s      = acos(coeffs)
                          gn2(irad) = -2.*sqrtq*cos((s+4.*pi)/3.) - b
 
                        else

c=======================================================================
c   limits the stomatal conductance to g0
c=======================================================================

                          b     = -0.5*(fac8 + gj*a1)
                          c     =              gj*fac7
                          roo   = b*b - a1*c
                          gn2(irad) = -(b + sqrt(roo))/a1

                        endif
                      endif
                    enddo
                  endif

                  if(gn1  .lt. 0.) gn1  = 0.
                  do irad = 1, 3
                    if(gn2(irad) .lt. 0.) gn2(irad) = 0.
                  enddo

                  if(gn3  .lt. 0.) gn3  = 0.

c=======================================================================
c   coupling of limitations
c=======================================================================

                  theta0 = 0.90
                  beta0  = 0.90

                  do irad = 1, 3
                    b1 = - 0.5*(gn1 + gn2(irad))
                    c1 = gn1 * gn2(irad)
                    rho1 = b1*b1 - theta0*c1
                    gn0 = -(b1 + sqrt(rho1))/theta0

                    b2 = - 0.5*(gn0 + gn3)
                    c2 = gn0 * gn3
                    rho2 = b2*b2 - beta0*c2
                    gnd(irad) = -(b2 + sqrt(rho2))/beta0

                    if(gnd(irad) .lt. 0.)  gnd(irad) = 0.
                  enddo

                  gn = sunhour(iday) * (fsun(ip,iday,ih) * gnd(1) 
     &               + (1.-fsun(ip,iday,ih)) * gnd(2))
     &               + (1. - sunhour(iday)) * gnd(3)
                  gn = gn * corr_hour(iday,ih)
                  zgpp(ip,iday) = zgpp(ip,iday)  + gn

CNPP                  znpp(ip,iday) = znpp(ip,iday) 
CNPP     &                               + gn - rd
c modification Wijk : g1new au lieu g1
                  gst = g0(ip) + g1new(iday,ip)*(gn-rd)*hs(iday,ih)/
     &                                                     co2a
                  if(gst.le.g0(ip)) gst = g0(ip)
                  rtot = 1.6/gst + rbl(ip,iday)
                  unitchg = unitfac * (1.+(tcel(iday)/temp0)) 
     &                              * patm0/patm
c rtot_w: total resistance for water vapour (s m-1) (stom+bl+aer)
c-----------------------------------------------------------------------
                  rtot_w = 1./(gst*unitchg)
     &                   + rbw(ip,iday) + rae(ip,iday)
                  co2cl = co2a - (gn-rd)*rtot
                  if(co2cl.le.0.) co2cl = 0. 

                  gca(ip,iday) = gca(ip,iday) + co2a / rtot
                  gci(ip,iday) = gci(ip,iday) + co2cl /rtot

                  fracth = delc1 + delc2(ip) * co2cl / co2a

                  zfract(ip,iday) = zfract(ip,iday)
     &                                 + fracth * gn
                  zfh2o(ip,iday) = zfh2o(ip,iday)
     &              + qsatmb(iday,ih)*100.*(1.-hs(iday,ih))
     &              / (rtot_w*rgas_v*temp(iday,ih))

          endif
        enddo

c=======================================================================
c   transformation into g m-2 day-1 for one lai layer
c=======================================================================


      zgpp(ip,iday) = zgpp(ip,iday) * transfo * (1. - snow_frac(iday))
CNPP              znpp(ip,iday) = znpp(ip,iday) * transfo
CNPP     &                           * (1. - snow_frac(iday))
      zfract(ip,iday) = zfract(ip,iday)*transfo * (1. - snow_frac(iday))
      zfh2o(ip,iday) = zfh2o(ip,iday) * transfw * (1. - snow_frac(iday))

      gca(ip,iday) = gca(ip,iday) * transfo * (1. - snow_frac(iday))
      gci(ip,iday) = gci(ip,iday) * transfo * (1. - snow_frac(iday))
      
      
c      do ipool = 1, npool
c        resp_fac_temp(ip,ipool,iday,ngt) 
c     &                       = resp_fac(ip,ipool,iday) 
c      enddo

c      gca_temp(ip,iday,ngt) = gca(ip,iday)
c      gci_temp(ip,iday,ngt) = gci(ip,iday)

c      zgpp_temp(ip,iday,ngt) = zgpp(ip,iday)  

c      zfract_temp(ip,iday,ngt) = zfract(ip,iday)
c      zfh2o_temp(ip,iday,ngt) = zfh2o(ip,iday)         

      return 
      end


c=======================================================================
c***********************************************************************
      subroutine lai_limit_w
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c     This routine calculates monthly lai limits to assure coherence
c     between CARAIB and IBM
c=======================================================================

      include './com_18/annee.common'
      include './com_18/parameter.common'
      include './com_18/bagnum.common'
      include './com_18/climin0.common'
      include './com_18/ecoin.common'
      include './com_18/laih2o.common'
      include './com_18/laiste.common'
      include './com_18/loop.common'
      include './com_18/monthcst.common'
      include './com_18/monwat.common'
      include './com_18/pho_sch.common'
      include './com_18/pnpp2.common'
      include './com_18/strate.common'
      include './com_18/tresh.common'
      include './com_18/xvalues.common'
c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer m
      real*4 corr_wat,etrmax,fh2o_mth,tmin0,wgt_yvs,xlai_mth
      
c-----------------------------------------------

      dimension fh2o_mth(nm),xlai_mth(nm)

      do ip = ipi,ipf
       if(frac(ip).gt.1.e-7) then

        do m = 1, nm
          fh2o_mth(m) = 0.
          xlai_mth(m) = 0.
        enddo
        do iday = 1,nd
          m = imonth(iday)
          fh2o_mth(m) = fh2o_mth(m) + zfh2o(ip,iday) * xlai(ip,iday)
          xlai_mth(m) = xlai_mth(m) + xlai(ip,iday)
        end do
        do m = 1, nm
          cfh2o(ip,m) = fh2o_mth(m)
          xlai_mth(m) = xlai_mth(m) / float(mlength(m))
        enddo   

        ylai_w(ip) = 0.
        wgt_yvs = 0.
        yvslai_w(ip) = 0. 
        yminlai_w(ip) = xlaimax

c rtrcar(m) = fraction of evaporation svecar(m) associated with 
c          vegetation transpiration
c-----------------------------------------------------------------------

        do m = 1, nm
          xlai_w(ip,m) = xlaimax        
          etrmax = rtrcar(m) * svecar(m)
          if(etrmax.lt.0.) etrmax = 0.

c------------------A CHANGER----------------------------------------
          if(cfh2o(ip,m).gt.0. .and. cfh2o(ip,m).gt.etrmax) then
             corr_wat = etrmax/cfh2o(ip,m)
CV8              if(nyr_t.eq.0) corr_wat = (1.+ (etrmax/cfh2o(ip,m)))/2.
             xlai_w(ip,m) = xlai_mth(m)*corr_wat
          endif
c-----------------A CHANGER------------------------------------------

          if (xlai_w(ip,m).le.0.) then
            xlai_w(ip,m) = 0.
          endif


          ylai_w(ip) = ylai_w(ip)+xlai_w(ip,m)
     &               * float(mlength(m))/float(nd)
          if (fsncar(m).lt.0.1) then
            if (idec(ip).eq.0) then 
              wgt_yvs = wgt_yvs+float(mlength(m))/float(nd)
              yvslai_w(ip) = yvslai_w(ip)+xlai_w(ip,m)
     &             * float(mlength(m))/float(nd)
              if(yminlai_w(ip).ge.xlai_w(ip,m))then
                yminlai_w(ip)=xlai_w(ip,m)
              endif
            elseif (idec(ip).eq.1) then
              tmin0 = tcel0(m)-tdiff0(m)/2.
              if (tmin0.gt.ttreshi1(ip)) then
                wgt_yvs = wgt_yvs+float(mlength(m))/float(nd)
                yvslai_w(ip) = yvslai_w(ip)+xlai_w(ip,m)
     &                      * float(mlength(m))/float(nd)
                if(yminlai_w(ip).ge.xlai_w(ip,m))then
                  yminlai_w(ip)=xlai_w(ip,m)
                endif
              endif
            elseif (idec(ip).eq.2) then 
              if (swcar(m).gt.wattresh1(ip)) then
                wgt_yvs = wgt_yvs+float(mlength(m))/float(nd)
                yvslai_w(ip) = yvslai_w(ip)+xlai_w(ip,m)
     &               * float(mlength(m))/float(nd)
                if(yminlai_w(ip).ge.xlai_w(ip,m))then
                  yminlai_w(ip)=xlai_w(ip,m)
                endif
              endif
            endif
          endif
        enddo

        if (wgt_yvs.gt.1.e-5) then
          yvslai_w(ip) = yvslai_w(ip)/wgt_yvs
        else
          yvslai_w(ip) = 0.
        endif

       endif
      enddo

      return 
      end

c=======================================================================
c***********************************************************************
      subroutine frac_trees(ngt)
c***********************************************************************
c=======================================================================  
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/annppf.common'
      include './com_18/ecoin.common'
      include './com_18/landuse.common'
      include './com_18/mois.common'
      include './com_18/nspc.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer ip
      real*4  tree_suc
      

c-----------------------------------------------
c=======================================================================
c   ynppf represents an annual npp 
c   if it is negative, it is set to 0 : a tree with 
c   a negative annual npp is considered as not present
c=======================================================================

      tree_suc = 0.
      do ip = nherb+nbush+1, npft0 
        if ((suc_est(ip,ngt).gt.1.e-5).and.(ynppf(ip).gt.1.e-5)) then
          tree_suc = tree_suc + suc_est(ip,ngt)*ynppf(ip)
        endif
      enddo 

      do ip = nherb+nbush+1, npft0
        if ((suc_est(ip,ngt).gt.1.e-5).and.(ynppf(ip).gt.1.e-5)) then
          frac(ip) = suc_est(ip,ngt)*frac_nat(ngt)*ynppf(ip)/tree_suc
        else
          frac(ip) = 0.
        endif
      enddo

      return
      end


c=======================================================================
c***********************************************************************
      subroutine solar_trees(ngt)
c***********************************************************************
c=======================================================================
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/ecoin.common'
      include './com_18/ext_con.common'
      include './com_18/landuse.common'
      include './com_18/loop.common'
      include './com_18/nspc.common'
      include './com_18/radcst.common'
      include './com_18/sol_in.common'
      include './com_18/xvalues.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer ih,irad
      real*4 facgk,facpkdif,frac_free,frac_tree_tot,gk,pkdif
      

c-----------------------------------------------
c========================================================================
c     cover fractions:
c         frac_tree_tot = total fraction of the pixel covered by trees
c         frac_free     = fraction of the pixel free from trees
c========================================================================

      frac_tree_tot = 0.
      if(frac_nat(ngt).gt.1.e-7) then
        do ip = nherb+nbush+1,npft0
          frac_tree_tot = frac_tree_tot + frac(ip)
        end do
        if(frac_tree_tot.gt.1.001*frac_nat(ngt)) then
         write(61,*) 'ERROR total cover of trees'
     &              ,frac_tree_tot,frac_nat(ngt)
         stop
        endif	
        frac_free = 1. - frac_tree_tot / frac_nat(ngt)
        if(frac_free.lt.0.) frac_free = 0.
        if(frac_free.gt.1.) frac_free = 1.
      else
        frac_tree_tot = 0.
	frac_free = 1.
      endif



c========================================================================
c     initialisation of the solar fluxes for the understorey:
c        par1 (photosynthetically active radiation)
c              1 direct radiation
c              2 diffuse radiation on sunny days
c              3 diffuse radiation on cloudy days
c        fsun0 fraction of sunlit leaves
c========================================================================

      do iday = 1, nd
        do ih = 1,nh2
          fsun0(iday,ih) = 1. * frac_free
          do irad = 1, 3
            par1(iday,ih,irad) = par0(iday,ih,irad) * frac_free
          end do
        end do
      end do

c========================================================================
c     calculation of solar fluxes and sunlit fraction for understorey
c========================================================================

      if(frac_free .lt. 1.) then
        do iday = 1, nd
          do ih = 1, nh2
            gk = 0.
            if(xmucar(iday,ih) .ne. 0.)  gk  = clump_fac * 0.5 
     &                                       / xmucar(iday,ih)
            pkdif = 0.8 * facome

            do ip = nherb+nbush+1,npft0
              if(frac(ip).gt.1.e-7) then
  
                facgk = - gk * xlai(ip,iday)
                if(facgk .lt. -40.) facgk = -40.
  
                fsun0(iday,ih) = fsun0(iday,ih) 
     &                         + exp(facgk) * frac(ip) / frac_nat(ngt)
                facpkdif = -pkdif    * xlai(ip,iday)
                if(facpkdif .lt. -40.) facpkdif = -40.

                par1(iday,ih,1) = par1(iday,ih,1) 
     &               + par0(iday,ih,1)*(1.-ome)*exp(facgk)
     &               * frac(ip) / frac_nat(ngt)
                par1(iday,ih,2) = par1(iday,ih,2)
     &               + par0(iday,ih,2)*(1.-rhoc0)*exp(facpkdif)
     &               * frac(ip) / frac_nat(ngt)
                par1(iday,ih,3) = par1(iday,ih,3) 
     &               + par0(iday,ih,3)*(1.-rhoc0)*exp(facpkdif)
     &               * frac(ip) /frac_nat(ngt)
              endif
            end do
          end do
        enddo
      endif

      return
      end

c=======================================================================
c***********************************************************************
      subroutine frac_herbs(ngt)
c***********************************************************************
c=======================================================================
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/annppf.common'
      include './com_18/ecoin.common'
      include './com_18/landuse.common'
      include './com_18/mois.common'
      include './com_18/nspc.common'

      
c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer ip
      real*4 herb_suc
      
c-----------------------------------------------
c=======================================================================
c   ynppf represents an annual npp 
c   if it is negative, it is set to 0 : an herb with 
c   a negative annual npp is considered as inexistant
c=======================================================================

      herb_suc = 0.
      do ip = 1, nherb+nbush 
        if ((suc_est(ip,ngt).gt.1.e-5).and.(ynppf(ip).gt.1.e-5)) then
          herb_suc = herb_suc + suc_est(ip,ngt)*ynppf(ip)
        endif
      enddo 

      do ip = 1, nherb+nbush
        if ((suc_est(ip,ngt).gt.1.e-5).and.(ynppf(ip).gt.1.e-5)) then
          frac(ip) = suc_est(ip,ngt)*frac_nat(ngt)*ynppf(ip)/herb_suc
        else
          frac(ip) = 0.
        endif

      enddo

      return
      end

c=======================================================================
c***********************************************************************
      subroutine fire(ngt)
c***********************************************************************
c=======================================================================
      implicit none
      
c=======================================================================
c     This routine calculates probability of fire and area burned 
c     INPUTS:
c     commons must be set and iday in common cte
c     OUTPUTS:
c     Pf = Probability of fire
c     frac_burn = fraction of the pixel burned
c     area_burn = area burned (m2)
c=======================================================================

      include './com_18/parameter.common' 
      include './com_18/annppf.common'
      include './com_18/abobio.common'
      include './com_18/burned.common'
      include './com_18/climin.common'
      include './com_18/coord.common'
      include './com_18/cstpi.common'
      include './com_18/cte.common'
      include './com_18/ecoin.common'
      include './com_18/fire_emi.common'
      include './com_18/firevpar.common'      
      include './com_18/griddata.common'      
c      include './com_18/inidata.common'
      include './com_18/landuse.common'
      include './com_18/litiere.common'
      include './com_18/nspc.common'
      include './com_18/npp.common'
      include './com_18/plant_evol.common'
      include './com_18/plant_pool.common'
      include './com_18/soil_marie.common'
      include './com_18/soil_pool.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer iday,iday2,ip,ipool,kpool

      real*4 area_mean,area_star,argth,beta_e,beta_m,
     &   beta_root,beta_xl,bio_low,bio_up,biom_ag,f_burned,
     &   fac_flash,facbio,g0wind,gwinds,h_broot,
     &   pbio,pign,pign_hum,pmst,q,uf_b,uf_p,ufmax,winkmh,
     &   xign,xlf_b,xlf_low,xlf_up
      
c-----------------------------------------------
      yfnoburn = 1.

      if(ifire.eq.1) then

       fday(nd) = 1.

       do iday = 1, nd

        iday2 = iday - 1
        if(iday.eq.1) iday2 = nd
	
c fraction of aboveground biomass for each pool and each pft (constant)
        do ip = 1, npft0
         do ipool = 1, npool
          if(ipool.eq.1)then 
           fag_pft(ip,ipool) = 1.00
          else
	   if (carbon(ip,2,iday2).ge.1.e-5) then 
            fag_pft(ip,ipool)= 
     &       1.- (root_biomass(ip,iday2)/carbon(ip,2,iday2))
           else
	    fag_pft(ip,ipool)=0.
	   endif
          endif 
         end do
        end do	

c Fire module from Arora and Boer, 2005. J. Geophys. Res., 110, G02008,
c                         doi  10:1029/2005JG000042 
   

c open writing file
c      open(10,file='./fire.res')


c  Que j'aime a faire connaitre un nombre utile aux sages
c  3  .1  4   1   5       9      2   6      5    3    5
c      pi = 3.14159265
c Lightning frequency (flashes/km2/month)
c       xl_flash(iday) = 0.41-0.41*cos(2.*pi*float(iday)/365.)
c Probability of extinguishing fire over one day

       q_extinc(iday) = 0.5

c Aboveground biomass for each plant biomf_ag (g C m-2)
c Aboveground biomass and litter carbon biom_ag (g C m-2)

       biom_ag = 0.
       do ip = 1, npft0
        biomf_ag(ip) = 0.
        do ipool = 1, npool
         biomf_ag(ip)=biomf_ag(ip) + 
     &          carbon(ip,ipool,iday2)*fag_pft(ip,ipool) 
        end do
        biom_ag = biom_ag + frac(ip)*biomf_ag(ip)
       end do
       do kpool = 1, 2
         biom_ag = biom_ag + xlit(kpool,iday2)
       end do

       Bio_low = 200.
       Bio_up = 1000.
       beta_e = 0.35
       xlf_low = 0.02
       xlf_up = 0.85
       pign_hum = 0.
       g0wind = 0.1
c maximum fire spread rate (km/day)
       ufmax = 86400.*0.13/1000.

c Fire Occurrence probability
c   Fire occurrence probability linked to biomass (Pbio)
       facbio = (biom_ag-Bio_low)/(Bio_up-Bio_low)
       Pbio = max(0.,min(1.,facbio))

c   Fire occurrence probability linked to soil moisture (Pmst)  
       beta_root = max(0.,min(1.,water(iday)))
       argth=1.75*beta_root/beta_e
       Pmst = 1. - tanh(argth*argth)

c   Fire occurrence probability linked to ignition source (Pign)
       fac_flash = (0.25*xl_flash(iday)-xlf_low)/(xlf_up-xlf_low)
       beta_xl = max(0.,min(1.,fac_flash))
       xIgn=beta_xl/(beta_xl+exp(1.5-6.*beta_xl))
       Pign = xIgn + (1.-xIgn)*pign_hum

c   Fire occurrence probability linked to all factors (Pf)
       Pf(iday) = Pbio*Pmst*Pign        

c Area burned  
c   dependence of fire spread on soil wetness (h_broot) (dimensionless)
       beta_m = 1.
       if (beta_root.le.beta_e) beta_m = beta_root/beta_e
       h_broot = (1-beta_m)*(1.-beta_m) 
c   dependence of fire spread on wind speed (gwinds)(dimensionless)
       winkmh = 3.6*win(iday)
       gwinds = 1.-(1.-g0wind)*exp(-winkmh*winkmh/2500.)
c   downwind fire propagation speed uf_p (km/day)
       uf_p = ufmax*gwinds*h_broot
c   backspread fire propagation speed uf_b (km/day)     
       uf_b = 0.2 * uf_p
c   length-to-breadth ratio of fire xLf_B (dimensionless)
       xLf_B = 1.+10.*(1.-exp(-0.017*winkmh))
c   Area burned in one day (area_star)
       area_star = pi*(uf_p+uf_b)*(uf_p+uf_b)/(4.*xLf_B)
c   Mean area (km2) burned per 1000 km2 (over the whole duration of fire) 
       q = q_extinc(iday)
       area_mean = area_star*(1.-q)*(2.-q)/(q*q)
       if (area_mean.lt.0.)area_mean=0.
       if (area_mean.gt.1000.)area_mean=1000.
c   Fraction burned
       f_burned = Pf(iday)*area_mean/1000.   
       

c   Non-burned fraction        
       fnoburn(iday) = 1. - f_burned
	
c   Yearly cumulated non-burned fraction                  
       yfnoburn = fnoburn(iday)*yfnoburn
	
c   Cumulated non-burned fraction at day iday 	
       fday(iday) = yfnoburn

c   Burned fraction
       frac_burn(iday) = fday(iday2)-fday(iday)
       if (frac_burn(iday).lt.0.) frac_burn(iday)=0.      
	
c   Area burned per pixel       (m2)
       area_burn(iday) = frac_burn(iday)*areapix(ngt)*frac_nat(ngt)
     		

        do ip = 1, npft0
          if (frac(ip).gt.1.e-7) then
	  
c=======================================================================
c     Fire carbon emission per PFT
c     emi_burn_veg = carbon emission for each pool per day and per m2 
c                    of PFT (g C m-2 day-1) 
c
c     The sum over ip of:
c       frac(ip)*(emi_burn_veg(ip,1,iday)+emi_burn_veg(ip,2,iday))
c     provides the total carbon emission by fires per day and per m2 
c=======================================================================

           emi_burn_veg(ip,1,iday) = 
     &       frac_burn(iday)*phi_L(ip)*carbon(ip,1,iday)
           emi_burn_veg(ip,2,iday) = frac_burn(iday)*phi_S(ip)
     &       *(carbon(ip,2,iday)-root_biomass(ip,iday))
     &       +frac_burn(iday)*phi_R(ip)*root_biomass(ip,iday)
     
c=======================================================================
c     Fire mortality per PFT
c     xlit_burn = litter production due to fire for each pool per day 
c                 and per m2 of PFT (g C m-2 day-1)
c
c     The sum over ip of:
c       frac(ip)*(xlit_burn(ip,1,iday)+xlit_burn(ip,2,iday))
c     provides the total litter production by fires per day and per m2
c======================================================================= 	
          
           xlit_burn(ip,1,iday) = 
     &       frac_burn(iday)*psi_L(ip)*carbon(ip,1,iday)
           xlit_burn(ip,2,iday) = frac_burn(iday)*psi_S(ip)
     &       *(carbon(ip,2,iday)-root_biomass(ip,iday))
     &       +frac_burn(iday)*psi_R(ip)*root_biomass(ip,iday)
     
           do ipool = 1, npool
               xlit_prod(ip,ipool,iday) = xlit_prod(ip,ipool,iday)
     &               + xlit_burn(ip,ipool,iday)                   
           enddo
            
          endif
       
         enddo
        
        enddo           
        
      endif

      return
      end

c=======================================================================
c***********************************************************************
      subroutine mortality(ngt)
c***********************************************************************
c======================================================================= 
      implicit none
      
      include './com_18/parameter.common' 
      include './com_18/ageclas.common'
      include './com_18/annppf.common'
      include './com_18/burned.common'
      include './com_18/coord.common'
      include './com_18/cte.common'
      include './com_18/cstmort.common'
      include './com_18/ecoin.common'
      include './com_18/ext_con2.common'
      include './com_18/mort.common'
      include './com_18/gk.common'
c      include './com_18/inidata.common'
      include './com_18/litiere.common'
      include './com_18/npp.common'
      include './com_18/nspc.common'
      include './com_18/plant_pool.common'
      include './com_18/prev_yr.common'      
      include './com_18/soil_marie.common'
      include './com_18/tresh.common'     

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer iday,iday2,ip,ipool
      
c-----------------------------------------------      

      
      
      real*4  ftmin_tempo(npft),fwat_tempo(npft),fnat_tempo(npft) 
      real*4 gkfall_tree,vigor,smallwat  
      
c=======================================================================
c     loss fraction
c======================================================================= 
 
      do ip = 1, npft
      
       ftot(ip) = 1.
       ftmin(ip) = 1.
       fwat(ip) = 1.
       fnat(ip) = 1.
       ftmin_tempo(ip) = 1.
       fwat_tempo(ip) = 1.
       fnat_tempo(ip) = 1.

       if (frac(ip).gt.1.e-7) then
         
        tmin_inf(ip) = ttreshi2(ip) - delta_tmin
        tmin_sup(ip) = ttreshi2(ip) + delta_tmin
	
	smallwat = max(0.02,wattresh2(ip))
        
        wat_inf(ip) = max(0.,smallwat * (1. - delta_watmin))
        wat_sup(ip) = min(1.,smallwat * (1. + delta_watmin))
	
        if ((ilgtree.eq.1).and.
     &   ((ip.ge.nherb+nbush+1).and.(ip.le.npft0))) then
         if (xlaimax_prv(ip).ge.0.1) then
	  vigor = max(0.,ybinc_prv(ip)/xlaimax_prv(ip))
	 else
	  vigor = 0.
	 endif
	 gkfall_tree = 0.000274/(1.+0.035*vigor) 
         fnat(ip) = 1. - gkfall_tree
	 
         write(61,'(2(1x,f8.3),1x,i2,5(1x,e12.5))')ylongi,ylati,ip
     & ,ybinc_prv(ip),xlaimax_prv(ip),vigor,gkfall_tree,fnat(ip)
	
        else
c         fnat(ip) = 1. - 1. / (365.*icyear_mean(ip,nclas(ip)))
c         fnat(ip) = 1. - 1. / (365.*icyear_max(ip,nclas(ip)))
         fnat(ip) = 1. - gk_fall(ip,2,1)

        endif
	

        ftemp(ip,nd) = 1.

        do iday = 1, nd 
        
          iday2 = iday - 1
          if(iday.eq.1) iday2 = nd
      
          if ((ilgtree.eq.1).and.
     &     ((ip.ge.nherb+nbush+1).and.(ip.le.npft0))) then
             ftmin(ip) = 1.
	     fwat(ip) = 1.
          else	        
             ftmin(ip) = 1.-gk_fall(ip,2,3)+gk_fall(ip,2,3)*
     &       (0.5*(1.+erf(xk_erf*(tmin2(iday)-ttreshi2(ip))/
     &                   delta_tmin))) 
             fwat(ip) = 1.-gk_fall(ip,2,2)+gk_fall(ip,2,2)*
     &       (0.5*(1.+erf(xk_erf*(water2(iday)-smallwat)/
     &                   (delta_watmin*smallwat))))                   
          endif

          if(ftmin(ip).lt.0. .or. ftmin(ip).gt.1.000001) then
              write(61,*) 'errrrrrror',ftmin(ip)
          endif
          
          ftot(ip) = ftot(ip)*ftmin(ip)*fwat(ip)*fnat(ip)  
          
          ftmin_tempo(ip) = ftmin_tempo(ip)*ftmin(ip)
          fwat_tempo(ip) = fwat_tempo(ip)*fwat(ip)
          fnat_tempo(ip) = fnat_tempo(ip)*fnat(ip)
          
          if(iday.eq.nd) then
            ftmin(ip) = ftmin_tempo(ip)
            fwat(ip) = fwat_tempo(ip)
            fnat(ip) = fnat_tempo(ip)
          endif
          
          ftemp(ip,iday) = ftot(ip)
          
c=======================================================================
c     litter production
c=======================================================================   
                  
          do ipool = 1, npool
c            if(iday.eq.1) then
c              xlit_newprod(ip,ipool,iday) = (1.-ftemp(ip,iday))
c     &                             *ycar_ini(ip,ipool,ngt)
c             else
               xlit_newprod(ip,ipool,iday) = (ftemp(ip,iday2)
     &                  -ftemp(ip,iday))*carbon(ip,ipool,iday2)
               xlit_prod(ip,ipool,iday) = xlit_prod(ip,ipool,iday)
     &                                  + xlit_newprod(ip,ipool,iday)
c             endif
                    
          enddo

        enddo
       endif            
       
       ftot(ip) = ftot(ip) * yfnoburn
       
      enddo
      

        
      return
      end


c=======================================================================
c**********************************************************************
      subroutine biomass_correction
c***********************************************************************
c=======================================================================
      implicit none
      
      include './com_18/parameter.common' 
      include './com_18/annppf.common'
      include './com_18/biomasse.common'
      include './com_18/dayres.common'
      include './com_18/ecoin.common'
      include './com_18/fire_emi.common'      
      include './com_18/npp.common'
      include './com_18/nspc.common'
      include './com_18/plant_pool.common'
      include './com_18/soil_marie.common'
      include './com_18/soil_pool.common' 
      integer iday,iday1,ip,ipool
      real*4 sum_xlit,sum_emi   

    
      do ip = 1,npft0       
       if ((frac(ip).gt.1.e-7)) then
        do iday = 1, nd
         do ipool = 1, npool
          sum_xlit = 0.
	  sum_emi = 0.
          do iday1 = 1, iday
           sum_xlit = sum_xlit + xlit_newprod(ip,ipool,iday1)
     &                           + xlit_burn(ip,ipool,iday1)
           sum_emi = sum_emi + emi_burn_veg(ip,ipool,iday1)     
          end do
          carbon(ip,ipool,iday) = carbon(ip,ipool,iday) 
     &                          - sum_xlit - sum_emi 
          if(carbon(ip,ipool,iday).lt.0.) carbon(ip,ipool,iday) = 0       
         enddo
        enddo                                     
       endif
      enddo
      
      return
      end


c=======================================================================
c**********************************************************************
      subroutine soil_resp(ngt)
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c   This routine estimates the monthly soil respiration rate
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/annee.common'
      include './com_18/annppf.common'
      include './com_18/biomasse.common'
      include './com_18/burned.common'      
      include './com_18/climin.common'
      include './com_18/cte.common'
      include './com_18/dayres.common'
      include './com_18/eco.common'
      include './com_18/ecoin.common'
      include './com_18/fire_emi.common'
      include './com_18/firevpar.common'      
      include './com_18/gama.common'
      include './com_18/griddata.common'
      include './com_18/landuse.common'      
      include './com_18/litiere.common'
      include './com_18/loop.common'
      include './com_18/mort.common'
      include './com_18/nspc.common'
      include './com_18/textcst1.common'
      include './com_18/soil_marie.common'
      include './com_18/soil_pool.common'
      include './com_18/smrd.common'
      include './com_18/sresp.common'
      include './com_18/varday.common'

      
c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer iday2,iyear,kpool,max_year
      
      real*4 b,cm,cmopt,cmoxm1,fin,fout,fsw,psat,rg,rt,tem10,
     &       test_conv,test_conv_max,testc,xlit_prod_tot,xm1  
     
c-----------------------------------------------   
      dimension xmresp(3,ndy),Fin_lit(2,ndy)
      real*4 xmresp,Fin_lit,phi_D_mean,sum_mean,totfrac


c=======================================================================
c   soil respiration factor calculation i.e. 
c               soil respiration
c              ------------------
c              soil carbon content
c=======================================================================

      xm1   = (xm1cla*cla   + xm1sil*sil   + xm1san*san)*0.01
      cmopt = (cmoptcla*cla + cmoptsil*sil + cmoptsan*san)*0.01
      psat  = (psatcla*cla  + psatsil*sil  + psatsan*san)*0.01  
      cmoxm1 = cmopt**xm1

      do iday = 1, nd

        xdnep(iday) = xdnpp(iday)

        tem10 = (tcel(iday) - 10.) / 10.

        cm  = ((fci-wpi)*water(iday) + wpi)/fsi
        b   = (cm**xm1-cmoxm1)/(1.-cmoxm1)
        fsw = 0.2 + 0.8 * psat**(b*b)
        rg  = facgrnd * (q10grnd**tem10)*fsw
        rt  = factree * (q10tree**tem10)*fsw

         xmresp(1,iday) = rg
         xmresp(2,iday) = rt
         xmresp(3,iday) = rt
      enddo

c=======================================================================
c   soil carbon estimation
c=======================================================================

      max_year = 1
      if(nys.eq.1) max_year = 1000
      test_conv_max = 0.001


       phi_D_mean  = 0.
       sum_mean = 0.

       do iday = 1, nd

        do kpool = 1, 2
          Fin_lit(kpool,iday) = 0.
         
        end do
	
	do ip = 1, npft
	  xlit_prod_tot=xlit_prod(ip,1,iday)+xlit_prod(ip,2,iday)
	  if (ip.le.npft0) phi_D_mean = phi_D_mean  
     &        + phi_D(ip) * xlit_prod_tot * frac(ip)
     	  sum_mean = sum_mean + xlit_prod_tot * frac(ip)

          Fin_lit(1,iday) = Fin_lit(1,iday) 
     &                    + xlit_prod(ip,1,iday)*frac(ip)
ctt          if(ip.le.nherb .or. ip.gt.npft0) then
ctt             Fin_lit(1,iday) = Fin_lit(1,iday) 
ctt     &                       + xlit_prod(ip,2,iday)*frac(ip)
ctt          else
             Fin_lit(2,iday) = Fin_lit(2,iday) 
     &                       + xlit_prod(ip,2,iday)*frac(ip)
ctt          endif

        end do 

        do kpool = 1, 2
          if(Fin_lit(kpool,iday).lt.0.) Fin_lit(kpool,iday) = 0.
        end do
       end do
       
       if (sum_mean.gt.1.e-10) then
         phi_D_mean = phi_D_mean/sum_mean
       else
         phi_D_mean = 0.
	     totfrac = 0.
	     do ip = 1, npft0
	       totfrac = totfrac + frac(ip)
	       phi_D_mean = phi_D_mean + frac(ip)*phi_D(ip)
	     end do
	     if (totfrac.gt.1.e-10) then
	       phi_D_mean = phi_D_mean*frac_nat(ngt)/totfrac
	     else
	       phi_D_mean = 0.
	     endif
       endif
       
c=======================================================================
c   Litter
c=======================================================================


          do kpool = 1, 2
            test_conv = 999999.
            iyear     = 0

c=======================================================================
c   beginning of integration loop
c=======================================================================

 8000       continue

            testc = xlit(kpool,nd)
            do iday = 1, nd

              iday2 = iday - 1
              if(iday.eq.1) iday2 = nd

c=======================================================================
c   incoming and outgoing fluxes
c=======================================================================


              Fout = gama1(kpool)*xmresp(kpool,iday)*xlit(kpool,iday2)
	      emi_burn_lit(iday) = frac_burn(iday) * phi_D_mean
     &                            * xlit(kpool,iday2)

              xhum_prod(kpool,iday) = alpha * Fout

c=======================================================================
c    pool calculation
c=======================================================================

              xlit(kpool,iday) = xlit(kpool,iday2)
     &                         + Fin_lit(kpool,iday) - Fout 
     &                         - emi_burn_lit(iday)
              if(xlit(kpool,iday).lt.0.01) xlit(kpool,iday) = 0.

            enddo

c=======================================================================
c    convergence test
c=======================================================================

            iyear = iyear + 1
            if(nys.eq.1) then

              if(xlit(kpool,nd).le.test_conv_max) then
                testc = abs(testc-xlit(kpool,nd))
              else
                testc = 100.*abs(testc-xlit(kpool,nd))
     &                / xlit(kpool,nd)
              endif
            else
              testc = 0.
            endif
            test_conv = testc
            if(iyear.ge.max_year) test_conv = 0.

c=======================================================================
c     end of integration loop
c=======================================================================

            if(test_conv.gt.test_conv_max) goto 8000

          enddo

c=======================================================================
c   HUMUS
c=======================================================================
c=======================================================================
c   first estimate of the humus pool:
c   initialisation for a steady state.
c=======================================================================

          test_conv = 9999999.
          iyear     = 0

c=======================================================================
c   beginning of integration loop
c=======================================================================

 8100     continue

          testc = xhumus(nd)

          do iday = 1, nd

            iday2 = iday - 1
            if(iday.eq.1) iday2 = nd

c=======================================================================
c   incoming and outgoing fluxes
c=======================================================================

            Fin = 0.

            do kpool = 1, 2
              Fin = Fin + xhum_prod(kpool,iday)
            enddo

            if(Fin .lt. 0.) Fin = 0.

            Fout = gama2 * xmresp(3,iday) * xhumus(iday2)

c=======================================================================
c    pool calculation
c=======================================================================

            xhumus(iday) = xhumus(iday2) + Fin - Fout
            if(xhumus(iday).lt.0.01) xhumus(iday) = 0.

          enddo

c=======================================================================
c   convergence test
c=======================================================================

          iyear = iyear + 1
          if(nys.eq.1) then

            if(xhumus(nd).le.test_conv_max) then
              testc = abs(testc-xhumus(nd))
            else
              testc = 100.*abs(testc-xhumus(nd))
     &              / xhumus(nd)
            endif

          else
            testc = 0.
          endif
          test_conv = testc
          if(iyear.ge.max_year) test_conv = 0.

c=======================================================================
c   end of integration loop
c=======================================================================

          if(test_conv.gt.test_conv_max) goto 8100

c=======================================================================
c    total soil carbon content and nep
c=======================================================================

       do iday = 1, nd
         ysoilr(1) = ysoilr(1) + xlit(1,iday)
         ysoilr(2) = ysoilr(2) + xlit(2,iday)
         ysoilr(3) = ysoilr(3) + xhumus(iday)
         xdnep(iday) = xdnep(iday) 
     &               - gama1(1)*xlit(1,iday)*xmresp(1,iday)*(1.-alpha)
     &               - gama1(2)*xlit(2,iday)*xmresp(2,iday)*(1.-alpha)
     &               - gama2*xhumus(iday)*xmresp(3,iday)
       end do

       do kpool = 1, 3
         ysoilr(kpool) = ysoilr(kpool) / float(nd)
         ysoilr(0) = ysoilr(0) + ysoilr(kpool)
       end do

      return
      end


      
c=======================================================================
c***********************************************************************
      subroutine new_frac(ngt)
c***********************************************************************
c======================================================================= 
      implicit none
      
      include './com_18/parameter.common'
      include './com_18/annppf.common'
      include './com_18/burned.common'
      include './com_18/coord.common' 
      include './com_18/cte.common'
      include './com_18/disper.common'
      include './com_18/ecoin.common'
      include './com_18/estab.common'
      include './com_18/files_car.common'
      include './com_18/frac_change.common'
      include './com_18/gddpix.common'
      include './com_18/inidata.common'
      include './com_18/init.common'
      include './com_18/input_par.common'
      include './com_18/landuse.common'      
      include './com_18/mort.common'
      include './com_18/npp.common'
      include './com_18/nspc.common'
      include './com_18/pho_sch.common'
      include './com_18/plheight.common'
      include './com_18/tresh.common'

c-----------------------------------------------
c JLP ajouté pour implicit none
c
      integer , intent(in) :: ngt
      
      integer ip
      real*4 herb_seed,tree_seed
      
c-----------------------------------------------
         
c=======================================================================
c     initialization
c=======================================================================      
      
       hole_herb = 0.
       hole_tree = 0.
       strat_herb = 0.
       strat_tree = 0.
       stratnew1 = 0.
       stratnew2 = 0.
       
       do ip = 1, npft0      
          
         if(ip.le.nherb+nbush) then
          strat_herb = strat_herb + frac(ip)
         else
          strat_tree = strat_tree + frac(ip)
         endif  

       enddo       
      
c=======================================================================
c     loss fraction
c=======================================================================        

      do ip = 1, npft0
              
       fracnew(ip) = ftot(ip)*frac(ip) 
               
      enddo
      
      do ip = 1, nherb+nbush
         stratnew1 = stratnew1 + fracnew(ip)
      enddo
      
      do ip = 1+nherb+nbush, npft0
         stratnew2 = stratnew2 + fracnew(ip)
      enddo
      
      do ip = 1, npft0
         perte(ip) = frac(ip)-fracnew(ip)
      enddo 

      
c      hole_herb = strat_herb-stratnew1
      hole_herb = frac_nat(ngt)-stratnew1
      if(hole_herb.lt.0.) hole_herb = 0.

c      hole_tree = strat_tree-stratnew2
      hole_tree = frac_nat(ngt)-stratnew2
      if(hole_tree.lt.0.) hole_tree = 0.
      
c=======================================================================
c     seed production
c=======================================================================
      
      do ip = 1, npft0              
        seed_prod(ip)  = 0.
        seed_estab(ip) = 0.
        dispin(ip)     = 0.
        dispout(ip)    = 0.
        frac_seed(ip)  = 0.
        density(ip)    = 0.
        if (suc_est(ip,ngt).gt.1.e-5) then
          density(ip) = 1.
          dispin(ip) = carb_init(ip,2)
          if(imig.eq.1.and.ip.eq.isp
c         if(ip.eq.isp
     &       .and.irfg(ngt).ne.1) then
              density(ip) = 0.
              dispin(ip) = 0.
           endif
        endif

      end do

      do ip = 1, npft0

        seed_prod(ip) = 
     &          Fgdd5(ip)*frac(ip)*ynppf(ip)+dispin(ip)-dispout(ip)
        seed_estab(ip) = 
     &                  FTmmin(ip)*Fwatmin(ip)*pgerm(ip)*seed_prod(ip)

      enddo  
      
      herb_seed = 0.
      tree_seed = 0.
      do ip = 1, nherb+nbush
        herb_seed = herb_seed + density(ip)*seed_estab(ip)
      enddo
      
      do ip = nherb+nbush+1, npft0
        tree_seed = tree_seed + density(ip)*seed_estab(ip)
      enddo
      
      if(herb_seed.gt.0.) then
        do ip = 1, nherb+nbush
          frac_seed(ip) = hole_herb
     &                         *(density(ip)*seed_estab(ip)/herb_seed)  
        enddo
      endif
      
      if(tree_seed.gt.0.) then
        do ip = nherb+nbush+1, npft0
          frac_seed(ip) = hole_tree
     &                   *(density(ip)*seed_estab(ip)/tree_seed)
        enddo
      endif
      
      do ip = 1, npft0
        frac(ip) = fracnew(ip) + frac_seed(ip)  
      enddo
      
      return
      end

c=======================================================================
c***********************************************************************
      subroutine wri_res
c***********************************************************************
c=======================================================================
      implicit none
c=======================================================================
c   This routine write results.
c=======================================================================

      include './com_18/parameter.common'
      include './com_18/angppf.common'
      include './com_18/annee.common'
      include './com_18/annppf.common'
      include './com_18/biomasse.common'
      include './com_18/burned.common'      
      include './com_18/cmoiRmin.common'      
      include './com_18/coord.common'
      include './com_18/crops.common'      
      include './com_18/cte.common'
      include './com_18/dayres.common'
      include './com_18/ecoin.common'
      include './com_18/fire_emi.common'      
      include './com_18/fracc13.common'
      include './com_18/frac_change.common'      
      include './com_18/gddpix.common'
      include './com_18/gridin2.common'
      include './com_18/iprt.common'
      include './com_18/loop.common'
      include './com_18/nspc.common'
      include './com_18/management.common'      
      include './com_18/monres.common'
      include './com_18/monthcst.common'
      include './com_18/monthcst2.common'
      include './com_18/mort.common'      
      include './com_18/plant_pool.common'
      include './com_18/plant_evol.common'      
      include './com_18/prt_ctrl.common'
      include './com_18/pzone.common'
      include './com_18/soil_pool.common'
      include './com_18/xvalues.common'


      character*100 formatw
c-----------------------------------------------
c JLP ajouté pour implicit none
c
    
      integer m,kpool

c-----------------------------------------------        
CC      real*4 tempo1(npft),tempo2(npft),tempo3(npft),tempo4,tempo5(npft)
CC     &       ,tempo6(npft),tempo7(npft),tempo8(npft)
      real*4 ylitr 

c=======================================================================
c   write annual and monthly results.
c       ynpp     = yearly npp;
c       ygpp     = yearly leaf gpp;
c       xmnpp    = monthly npp;
c       xmnep    = monthly nep;
c       xmlai    = monthly mean leaf area index.
c       xmbiom   = monthly mean total biomass
c=======================================================================

      do ip = 1, npft
        yraf(ip) = ygppf(ip) - ynppf(ip)
      end do

      do iday = 1, nd
        xdra(iday) = xdgpp(iday) - xdnpp(iday)
	xdrh(iday) = xdnpp(iday) - xdnep(iday)
        xdemifire(iday) = emi_burn_lit(iday)
	do ip = 1, npft
	 xra(ip,iday) = xgpp(ip,iday) - xnpp(ip,iday)
	 xdemifire(iday) = xdemifire(iday)+frac(ip)*xemifire(ip,iday)
	 xdcharvest(iday)= xdcharvest(iday)+frac(ip)*xcharvest(ip,iday)	 
	end do
	xdnbp(iday) = xdnep(iday) - xdemifire(iday) - xdcharvest(iday)
      end do

      do iday = 1, nd
        m = imonth(iday)
        xmnpp(m) = xmnpp(m) + xdnpp(iday)
        xmgpp(m) = xmgpp(m) + xdgpp(iday)
	xmra(m) = xmra(m) + xdra(iday)
	xmrh(m) = xmrh(m) + xdrh(iday)
        xmnep(m) = xmnep(m) + xdnep(iday)
	xmnbp(m) = xmnbp(m) + xdnbp(iday)
	xmemifire(m) = xmemifire(m) + xdemifire(iday)
	xmcharvest(m) = xmcharvest(m) + xdcharvest(iday)
	xmemiblit(m) = xmemiblit(m) + emi_burn_lit(iday)
        xmlai(m) = xmlai(m) + xdlai(iday)
        xmbiom(m) = xmbiom(m) + xdbiom(iday)
        xmPnf(m) = xmPnf(m) * (1.-Pf(iday))
        xmfapar(m) = xmfapar(m) + xdfapar(iday)
        xmfrac_burn(m) = xmfrac_burn(m) + frac_burn(iday)
        xmarea_burn(m) = xmarea_burn(m) + area_burn(iday)
      enddo

      do m = 1, nm
        xmnpp(m) = xmnpp(m) * xmfac(m) 
        xmgpp(m) = xmgpp(m) * xmfac(m)
	    xmra(m) = xmra(m) * xmfac(m)
	    xmrh(m) = xmrh(m) * xmfac(m)
        xmnep(m) = xmnep(m) * xmfac(m)
	    xmnbp(m) = xmnbp(m) * xmfac(m)
	    xmemifire(m) = xmemifire(m) * xmfac(m)
	    xmcharvest(m) = xmcharvest(m) * xmfac(m)
	    xmemiblit(m) = xmemiblit(m) * xmfac(m)
        xmlai(m) = xmlai(m) / float(mlength(m))
        xmfapar(m) = xmfapar(m) / float(mlength(m))
        xmbiom(m) = xmbiom(m) / float(mlength(m))
        xmfrac_burn(m) = xmfrac_burn(m) * xmfac(m)
        xmarea_burn(m) = xmarea_burn(m) * xmfac(m)
        xmPf(m) = 1. - xmPnf(m) 
      enddo
c       write(*,*)'Frac w',ifrac,iprt_frac,imig,nyr_t,npft
c       if ((ifrac.eq.1.and.imig.eq.0).or.   
c     &     (ifrac.eq.1.and.imig.eq.1.and.nyr_t.eq.0)) then  ! marie
cc       if (ifrac.eq.1) then
c       if ((imig.eq.0).or.(imig.eq.1.and.nyr_t.eq.0)) then
        if(iprt_frac.eq.1) then
          write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f10.8))'	  
          write(60,formatw) ylongi,ylati,(frac(ip),ip=1,npft)
        endif 
c       endif
       
       write(formatw,*)'(2(f8.3,1x),',2*npft,'(f5.2,1x))'       
       if(iprt_laimin.eq.1)
     &    write(64,formatw) ylongi,ylati,(xlai_min(ip),ip=1,npft)
     &                     ,(xlai_max(ip),ip=1,npft)       
             
c beginning of if statement on iyprt
      if (iyprt.ge.1) then
      
       if (idaily_out.eq.0) then
        write(formatw,*)'(f8.3,1x,f8.3,',nm,'(1x,f11.2))'
        if(iprt_biomm.eq.1)
     &    write(55,formatw)ylongi,ylati,(xmbiom(m),m=1,nm)
        if(iprt_gppm.eq.1) 
     &    write(56,formatw)ylongi,ylati,(xmgpp(m),m=1,nm)
        if(iprt_ram.eq.1) 
     &    write(556,formatw)ylongi,ylati,(xmra(m),m=1,nm)     
        if(iprt_nppm.eq.1)
     &    write(57,formatw)ylongi,ylati,(xmnpp(m),m=1,nm)
        if(iprt_nepm.eq.1)
     &    write(58,formatw)ylongi,ylati,(xmnep(m),m=1,nm)
        if(iprt_rhm.eq.1) 
     &    write(558,formatw)ylongi,ylati,(xmrh(m),m=1,nm)     
        if(iprt_laim.eq.1)
     &    write(59,formatw)ylongi,ylati,(xmlai(m),m=1,nm)
        if(iprt_emifirem.eq.1)
     &    write(559,formatw)ylongi,ylati,(xmemifire(m),m=1,nm)
        if(iprt_emiblitm.eq.1)
     &    write(560,formatw)ylongi,ylati,(xmemiblit(m),m=1,nm)     
        if(iprt_nbpm.eq.1)
     &    write(561,formatw)ylongi,ylati,(xmnbp(m),m=1,nm)
        if ((imanag.eq.1).or.(ncrop.gt.0)) then
	 if(iprt_harvm.eq.1)
     &     write(562,formatw)ylongi,ylati,(xmcharvest(m),m=1,nm)
	endif               
        write(formatw,*)'(f8.3,1x,f8.3,',nm,'(1x,f6.3))'
        if(iprt_faparm.eq.1)
     &    write(98,formatw)ylongi,ylati,(xmfapar(m),m=1,nm)
       else
        write(formatw,*)'(f8.3,1x,f8.3,',nd,'(1x,f11.2))'
        if(iprt_biomm.eq.1)
     &    write(55,formatw)ylongi,ylati,(xdbiom(iday),iday=1,nd)        
        if(iprt_gppm.eq.1) 
     &    write(56,formatw)ylongi,ylati,(xdgpp(iday),iday=1,nd)
        if(iprt_ram.eq.1) 
     &    write(556,formatw)ylongi,ylati,(xdra(iday),iday=1,nd)     
        if(iprt_nppm.eq.1)
     &    write(57,formatw)ylongi,ylati,(xdnpp(iday),iday=1,nd)
        if(iprt_nepm.eq.1)
     &    write(58,formatw)ylongi,ylati,(xdnep(iday),iday=1,nd)
        if(iprt_rhm.eq.1) 
     &    write(558,formatw)ylongi,ylati,(xdrh(iday),iday=1,nd)     
        if(iprt_laim.eq.1)
     &    write(59,formatw)ylongi,ylati,(xdlai(iday),iday=1,nd)
        if(iprt_emifirem.eq.1)
     &    write(559,formatw)ylongi,ylati,(xdemifire(iday),iday=1,nd)
        if(iprt_emiblitm.eq.1)
     &    write(560,formatw)ylongi,ylati,(emi_burn_lit(iday),iday=1,nd)     
        if(iprt_nbpm.eq.1)
     &    write(561,formatw)ylongi,ylati,(xdnbp(iday),iday=1,nd)
        if ((imanag.eq.1).or.(ncrop.gt.0)) then
	 if(iprt_harvm.eq.1)
     &     write(562,formatw)ylongi,ylati,(xdcharvest(iday),iday=1,nd)
	endif     		       
       endif
       if (iyprt.eq.1) then
         write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f11.2))'
         if(iprt_nppf.eq.1)
     &    write(62,formatw) ylongi,ylati,(ynppf(ip),ip=1,npft)
         if(iprt_gpp.eq.1)
     &    write(65,formatw) ylongi,ylati,(ygppf(ip),ip=1,npft)
         if(iprt_raf.eq.1)
     &    write(565,formatw) ylongi,ylati,(yraf(ip),ip=1,npft)
         if(iprt_emifiref.eq.1)
     &    write(665,formatw) ylongi,ylati,(yemifiref(ip),ip=1,npft)               
         elseif (iyprt.eq.2) then
          write(formatw,*)'(',nd,'(1x,f6.2))'
	      if(iprt_nppf.eq.1) then
            write(62,'(f8.3,1x,f8.3)') ylongi,ylati
	      do ip = 1, npft
            write(62,formatw) (xnpp(ip,iday),iday=1,nd)
	      end do
	     endif	  
	     if(iprt_gpp.eq.1) then
          write(65,'(f8.3,1x,f8.3)') ylongi,ylati
          do ip = 1, npft
	       write(65,formatw) (xgpp(ip,iday),iday=1,nd)
	      end do
	     endif
	     if(iprt_raf.eq.1) then
          write(565,'(f8.3,1x,f8.3)') ylongi,ylati
	      do ip = 1, npft
	        write(565,formatw) (xra(ip,iday),iday=1,nd)
	      end do
	     endif
         if(iprt_emifiref.eq.1) then
          write(665,'(f8.3,1x,f8.3)') ylongi,ylati
	      do ip = 1, npft
	        write(665,formatw) (xemifire(ip,iday),iday=1,nd)
	      end do
	     endif			   
      endif
       
       write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f11.2))'
       if(iprt_Cveg.eq.1)
     &    write(66,formatw) ylongi,ylati,(ybiomf(ip),ip=1,npft)
       if(iprt_Csoil.eq.1) then
          ylitr=ysoilr(1)+ysoilr(2)
          write(67,6767) ylongi,ylati,ysoilr(0),ylitr
     &                  ,(ysoilr(kpool),kpool=1,3)
       endif
 6767  format(f8.3,1x,f8.3,5(1x,f11.2))
       if(iprt_frcC13.eq.1)
     &    write(68,formatw) ylongi,ylati,(yfractf(ip),ip=1,npft)
       write(formatw,*)'(2(f8.3,1x),',npft,'(f9.2,1x))'
       if(iprt_Rmin.eq.1)
     &    write(63,formatw) ylongi,ylati,(R_min(ip),ip=1,npft)
     
       if (iyprt.eq.1) then
        write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f6.3))'
        if(iprt_laimoy.eq.1)  
     &    write(69,formatw) ylongi,ylati,(xlai_moy(ip),ip=1,npft)
       elseif (iyprt.eq.2) then
        write(formatw,*)'(',nd,'(1x,f6.3))'
	write(69,'(f8.3,1x,f8.3)') ylongi,ylati
	do ip = 1, npft
	 write(69,formatw) (xlai(ip,iday),iday=1,nd)
	end do
       endif
        

       if (ifire.eq.1) then
        if (idaily_out.eq.0) then
c monthly results of fire module
         write(formatw,*)'(f8.3,1x,f8.3,',nm,'(1x,1pe9.2))'
         if(iprt_fire.eq.1) 
     &     write(73,formatw)ylongi,ylati,(xmPf(m),m=1,nm)
         if(iprt_fburn.eq.1)
     &     write(74,formatw)ylongi,ylati,(xmfrac_burn(m),m=1,nm)
         if(iprt_aburn.eq.1)
     &     write(75,formatw)ylongi,ylati,(xmarea_burn(m),m=1,nm)
        else
c daily results of fire module
         write(formatw,*)'(f8.3,1x,f8.3,',nd,'(1x,1pe9.2))'
         if(iprt_fire.eq.1) 
     &     write(73,formatw)ylongi,ylati,(Pf(iday),iday=1,nd)
         if(iprt_fburn.eq.1)
     &     write(74,formatw)ylongi,ylati,(frac_burn(iday),iday=1,nd)
         if(iprt_aburn.eq.1)
     &     write(75,formatw)ylongi,ylati,(area_burn(iday),iday=1,nd)    
        endif           
       endif
       
       if ((imanag.eq.1).or.(ncrop.gt.0)) then
        write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f11.2))'      
        if(iprt_harv.eq.1)
     &     write(79,formatw)ylongi,ylati,(ycharvest(ip),ip=1,npft)
       endif       
       
c       tempo4 = yfnoburn
c       yfnoburn = -1.
       
CC      do ip = 1, npft       
CC       if (frac(ip).lt.1.e-7) then
CC        tempo1(ip) = ftmin(ip)
CC        ftmin(ip) = -1.
CC        tempo2(ip) = fwat(ip)
CC        fwat(ip) = -1.
CC        tempo3(ip) = ftot(ip)
CC        ftot(ip) = -1.
CC        tempo5(ip) = Fgdd5(ip)
CC        Fgdd5(ip) = -1.
CC        tempo6(ip) = FTmmin(ip)
CC        FTmmin(ip) = -1.
CC        tempo7(ip) = Fwatmin(ip)
CC        Fwatmin(ip) = -1.
CC        tempo8(ip) = fnat(ip)
CC        fnat(ip) = -1.
CC       endif  
CC      enddo
       
       if (ifrac.eq.1) then
       
        write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f12.8))'
c        if(iprt_yfnoburn.eq.1) 
c     &     write(83,'(f8.3,1x,f8.3,1x,f10.8)')ylongi,ylati,yfnoburn
        if(iprt_ftomin.eq.1)
     &     write(84,formatw)ylongi,ylati,(ftmin(ip),ip=1,npft)
        if(iprt_ftotw.eq.1)
     &     write(85,formatw)ylongi,ylati,(fwat(ip),ip=1,npft)
c        if(iprt_ftot.eq.1)
c     &     write(86,formatw)ylongi,ylati,(ftot(ip),ip=1,npft)
       endif
       
c       if (imig.eq.1) then
       
c        write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f10.8))'
c        if(iprt_Fgdd5.eq.1)
c     &     write(87,formatw)ylongi,ylati,(Fgdd5(ip),ip=1,npft)
c        if(iprt_FTmmin.eq.1)
c     &     write(88,formatw)ylongi,ylati,(FTmmin(ip),ip=1,npft)
c        if(iprt_Fwatmin.eq.1)
c     &     write(89,formatw)ylongi,ylati,(Fwatmin(ip),ip=1,npft)
c       endif

c end of if statement on iyprt       
      endif

c       write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f11.2))'
c       if(iprt_nppf.eq.1) 
c     &    write(62,formatw) ylongi,ylati,(ynppf(ip),ip=1,npft)
       
       if (ifrac.eq.1) then
       
        write(formatw,*)'(f8.3,1x,f8.3,1x,f12.8,',npft,'(1x,f12.8))'
        if(iprt_yfnoburn.eq.1) 
     &     write(83,formatw)
     &     ylongi,ylati,yfnoburn,(fnat(ip),ip=1,npft)
        write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f12.8))'
        if(iprt_ftot.eq.1)
     &     write(86,formatw)ylongi,ylati,(ftot(ip),ip=1,npft)
        endif
       
c       if (imig.eq.1) then
       
        write(formatw,*)'(f8.3,1x,f8.3,',npft,'(1x,f12.8))'
        if(iprt_Fgdd5.eq.1)
     &     write(87,formatw)ylongi,ylati,(Fgdd5(ip),ip=1,npft)
        if(iprt_FTmmin.eq.1)
     &     write(88,formatw)ylongi,ylati,(FTmmin(ip),ip=1,npft)
        if(iprt_Fwatmin.eq.1)
     &     write(89,formatw)ylongi,ylati,(Fwatmin(ip),ip=1,npft)
c       endif

c       yfnoburn = tempo4
         
CC      do ip = 1, npft       
CC       if (frac(ip).lt.1.e-7) then
CC        ftmin(ip) = tempo1(ip)
CC        fwat(ip) = tempo2(ip)
CC        ftot(ip) = tempo3(ip)
CC        Fgdd5(ip) = tempo5(ip)
CC        FTmmin(ip) = tempo6(ip)
CC        Fwatmin(ip) = tempo7(ip)
CC        fnat(ip) = tempo8(ip)
CC       endif  
CC      enddo

 1000 format(6(1x,f6.1),7(1x,f8.0))
 1200 format(12(1x,f5.2))
 1500 format(i3)

      return
      end

   
